/* about.c generated by valac 0.38.8, the Vala compiler
 * generated from about.vala, do not modify */

/*
   Copyright (C) 2013 André Stösel <andre@stoesel.de>
   Copyright (C) 2014 Christian Dywan <christian@twotoasts.de>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   See the file COPYING for the full license text.
*/

#include <glib.h>
#include <glib-object.h>
#include "midori/midori-view.h"
#include <stdlib.h>
#include <string.h>
#include "midori-core.h"
#include "webkit/webkit.h"
#include "midori/midori-websettings.h"
#include <glib/gi18n-lib.h>
#include "midori/midori-browser.h"
#include <gtk/gtk.h>
#include "midori/midori-extension.h"
#include "midori/midori-app.h"
#include "about.h"


#define ABOUT_TYPE_PAGE (about_page_get_type ())
#define ABOUT_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), ABOUT_TYPE_PAGE, AboutPage))
#define ABOUT_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), ABOUT_TYPE_PAGE, AboutPageClass))
#define ABOUT_IS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), ABOUT_TYPE_PAGE))
#define ABOUT_IS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), ABOUT_TYPE_PAGE))
#define ABOUT_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), ABOUT_TYPE_PAGE, AboutPageClass))

typedef struct _AboutPage AboutPage;
typedef struct _AboutPageClass AboutPageClass;
typedef struct _AboutPagePrivate AboutPagePrivate;
enum  {
	ABOUT_PAGE_0_PROPERTY,
	ABOUT_PAGE_URI_PROPERTY,
	ABOUT_PAGE_NUM_PROPERTIES
};
static GParamSpec* about_page_properties[ABOUT_PAGE_NUM_PROPERTIES];

#define ABOUT_TYPE_WIDGETS (about_widgets_get_type ())
#define ABOUT_WIDGETS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), ABOUT_TYPE_WIDGETS, AboutWidgets))
#define ABOUT_WIDGETS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), ABOUT_TYPE_WIDGETS, AboutWidgetsClass))
#define ABOUT_IS_WIDGETS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), ABOUT_TYPE_WIDGETS))
#define ABOUT_IS_WIDGETS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), ABOUT_TYPE_WIDGETS))
#define ABOUT_WIDGETS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), ABOUT_TYPE_WIDGETS, AboutWidgetsClass))

typedef struct _AboutWidgets AboutWidgets;
typedef struct _AboutWidgetsClass AboutWidgetsClass;
typedef struct _AboutWidgetsPrivate AboutWidgetsPrivate;
enum  {
	ABOUT_WIDGETS_0_PROPERTY,
	ABOUT_WIDGETS_URI_PROPERTY,
	ABOUT_WIDGETS_NUM_PROPERTIES
};
static GParamSpec* about_widgets_properties[ABOUT_WIDGETS_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))

#define ABOUT_TYPE_VERSION (about_version_get_type ())
#define ABOUT_VERSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), ABOUT_TYPE_VERSION, AboutVersion))
#define ABOUT_VERSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), ABOUT_TYPE_VERSION, AboutVersionClass))
#define ABOUT_IS_VERSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), ABOUT_TYPE_VERSION))
#define ABOUT_IS_VERSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), ABOUT_TYPE_VERSION))
#define ABOUT_VERSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), ABOUT_TYPE_VERSION, AboutVersionClass))

typedef struct _AboutVersion AboutVersion;
typedef struct _AboutVersionClass AboutVersionClass;
typedef struct _AboutVersionPrivate AboutVersionPrivate;
enum  {
	ABOUT_VERSION_0_PROPERTY,
	ABOUT_VERSION_URI_PROPERTY,
	ABOUT_VERSION_NUM_PROPERTIES
};
static GParamSpec* about_version_properties[ABOUT_VERSION_NUM_PROPERTIES];
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_string_free0(var) ((var == NULL) ? NULL : (var = (g_string_free (var, TRUE), NULL)))

#define ABOUT_TYPE_PRIVATE (about_private_get_type ())
#define ABOUT_PRIVATE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), ABOUT_TYPE_PRIVATE, AboutPrivate))
#define ABOUT_PRIVATE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), ABOUT_TYPE_PRIVATE, AboutPrivateClass))
#define ABOUT_IS_PRIVATE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), ABOUT_TYPE_PRIVATE))
#define ABOUT_IS_PRIVATE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), ABOUT_TYPE_PRIVATE))
#define ABOUT_PRIVATE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), ABOUT_TYPE_PRIVATE, AboutPrivateClass))

typedef struct _AboutPrivate AboutPrivate;
typedef struct _AboutPrivateClass AboutPrivateClass;
typedef struct _AboutPrivatePrivate AboutPrivatePrivate;
enum  {
	ABOUT_PRIVATE_0_PROPERTY,
	ABOUT_PRIVATE_URI_PROPERTY,
	ABOUT_PRIVATE_NUM_PROPERTIES
};
static GParamSpec* about_private_properties[ABOUT_PRIVATE_NUM_PROPERTIES];

#define ABOUT_TYPE_PATHS (about_paths_get_type ())
#define ABOUT_PATHS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), ABOUT_TYPE_PATHS, AboutPaths))
#define ABOUT_PATHS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), ABOUT_TYPE_PATHS, AboutPathsClass))
#define ABOUT_IS_PATHS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), ABOUT_TYPE_PATHS))
#define ABOUT_IS_PATHS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), ABOUT_TYPE_PATHS))
#define ABOUT_PATHS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), ABOUT_TYPE_PATHS, AboutPathsClass))

typedef struct _AboutPaths AboutPaths;
typedef struct _AboutPathsClass AboutPathsClass;
typedef struct _AboutPathsPrivate AboutPathsPrivate;
enum  {
	ABOUT_PATHS_0_PROPERTY,
	ABOUT_PATHS_URI_PROPERTY,
	ABOUT_PATHS_NUM_PROPERTIES
};
static GParamSpec* about_paths_properties[ABOUT_PATHS_NUM_PROPERTIES];

#define ABOUT_TYPE_DIAL (about_dial_get_type ())
#define ABOUT_DIAL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), ABOUT_TYPE_DIAL, AboutDial))
#define ABOUT_DIAL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), ABOUT_TYPE_DIAL, AboutDialClass))
#define ABOUT_IS_DIAL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), ABOUT_TYPE_DIAL))
#define ABOUT_IS_DIAL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), ABOUT_TYPE_DIAL))
#define ABOUT_DIAL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), ABOUT_TYPE_DIAL, AboutDialClass))

typedef struct _AboutDial AboutDial;
typedef struct _AboutDialClass AboutDialClass;
typedef struct _AboutDialPrivate AboutDialPrivate;
enum  {
	ABOUT_DIAL_0_PROPERTY,
	ABOUT_DIAL_URI_PROPERTY,
	ABOUT_DIAL_NUM_PROPERTIES
};
static GParamSpec* about_dial_properties[ABOUT_DIAL_NUM_PROPERTIES];
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define ABOUT_TYPE_GEOLOCATION (about_geolocation_get_type ())
#define ABOUT_GEOLOCATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), ABOUT_TYPE_GEOLOCATION, AboutGeolocation))
#define ABOUT_GEOLOCATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), ABOUT_TYPE_GEOLOCATION, AboutGeolocationClass))
#define ABOUT_IS_GEOLOCATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), ABOUT_TYPE_GEOLOCATION))
#define ABOUT_IS_GEOLOCATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), ABOUT_TYPE_GEOLOCATION))
#define ABOUT_GEOLOCATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), ABOUT_TYPE_GEOLOCATION, AboutGeolocationClass))

typedef struct _AboutGeolocation AboutGeolocation;
typedef struct _AboutGeolocationClass AboutGeolocationClass;
typedef struct _AboutGeolocationPrivate AboutGeolocationPrivate;
enum  {
	ABOUT_GEOLOCATION_0_PROPERTY,
	ABOUT_GEOLOCATION_URI_PROPERTY,
	ABOUT_GEOLOCATION_NUM_PROPERTIES
};
static GParamSpec* about_geolocation_properties[ABOUT_GEOLOCATION_NUM_PROPERTIES];

#define ABOUT_TYPE_REDIRECTS (about_redirects_get_type ())
#define ABOUT_REDIRECTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), ABOUT_TYPE_REDIRECTS, AboutRedirects))
#define ABOUT_REDIRECTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), ABOUT_TYPE_REDIRECTS, AboutRedirectsClass))
#define ABOUT_IS_REDIRECTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), ABOUT_TYPE_REDIRECTS))
#define ABOUT_IS_REDIRECTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), ABOUT_TYPE_REDIRECTS))
#define ABOUT_REDIRECTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), ABOUT_TYPE_REDIRECTS, AboutRedirectsClass))

typedef struct _AboutRedirects AboutRedirects;
typedef struct _AboutRedirectsClass AboutRedirectsClass;
typedef struct _AboutRedirectsPrivate AboutRedirectsPrivate;
enum  {
	ABOUT_REDIRECTS_0_PROPERTY,
	ABOUT_REDIRECTS_URI_PROPERTY,
	ABOUT_REDIRECTS_NUM_PROPERTIES
};
static GParamSpec* about_redirects_properties[ABOUT_REDIRECTS_NUM_PROPERTIES];

#define ABOUT_TYPE_MANAGER (about_manager_get_type ())
#define ABOUT_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), ABOUT_TYPE_MANAGER, AboutManager))
#define ABOUT_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), ABOUT_TYPE_MANAGER, AboutManagerClass))
#define ABOUT_IS_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), ABOUT_TYPE_MANAGER))
#define ABOUT_IS_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), ABOUT_TYPE_MANAGER))
#define ABOUT_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), ABOUT_TYPE_MANAGER, AboutManagerClass))

typedef struct _AboutManager AboutManager;
typedef struct _AboutManagerClass AboutManagerClass;
typedef struct _AboutManagerPrivate AboutManagerPrivate;
enum  {
	ABOUT_MANAGER_0_PROPERTY,
	ABOUT_MANAGER_NUM_PROPERTIES
};
static GParamSpec* about_manager_properties[ABOUT_MANAGER_NUM_PROPERTIES];

struct _AboutPage {
	GObject parent_instance;
	AboutPagePrivate * priv;
};

struct _AboutPageClass {
	GObjectClass parent_class;
	void (*get_contents) (AboutPage* self, MidoriView* view, const gchar* uri);
	const gchar* (*get_uri) (AboutPage* self);
	void (*set_uri) (AboutPage* self, const gchar* value);
};

struct _AboutWidgets {
	AboutPage parent_instance;
	AboutWidgetsPrivate * priv;
};

struct _AboutWidgetsClass {
	AboutPageClass parent_class;
};

struct _AboutWidgetsPrivate {
	gchar* _uri;
};

struct _AboutVersion {
	AboutPage parent_instance;
	AboutVersionPrivate * priv;
};

struct _AboutVersionClass {
	AboutPageClass parent_class;
};

struct _AboutVersionPrivate {
	gchar* _uri;
	GHashTable* about_pages;
};

struct _AboutPrivate {
	AboutPage parent_instance;
	AboutPrivatePrivate * priv;
};

struct _AboutPrivateClass {
	AboutPageClass parent_class;
};

struct _AboutPrivatePrivate {
	gchar* _uri;
};

struct _AboutPaths {
	AboutPage parent_instance;
	AboutPathsPrivate * priv;
};

struct _AboutPathsClass {
	AboutPageClass parent_class;
};

struct _AboutPathsPrivate {
	gchar* _uri;
};

struct _AboutDial {
	AboutPage parent_instance;
	AboutDialPrivate * priv;
};

struct _AboutDialClass {
	AboutPageClass parent_class;
};

struct _AboutDialPrivate {
	gchar* _uri;
};

struct _AboutGeolocation {
	AboutPage parent_instance;
	AboutGeolocationPrivate * priv;
};

struct _AboutGeolocationClass {
	AboutPageClass parent_class;
};

struct _AboutGeolocationPrivate {
	gchar* _uri;
};

struct _AboutRedirects {
	AboutPage parent_instance;
	AboutRedirectsPrivate * priv;
};

struct _AboutRedirectsClass {
	AboutPageClass parent_class;
};

struct _AboutRedirectsPrivate {
	gchar* _uri;
	gchar* property;
};

struct _AboutManager {
	MidoriExtension parent_instance;
	AboutManagerPrivate * priv;
};

struct _AboutManagerClass {
	MidoriExtensionClass parent_class;
};

struct _AboutManagerPrivate {
	GHashTable* about_pages;
};


static gpointer about_page_parent_class = NULL;
static gpointer about_widgets_parent_class = NULL;
static gpointer about_version_parent_class = NULL;
static gpointer about_private_parent_class = NULL;
static gpointer about_paths_parent_class = NULL;
static gpointer about_dial_parent_class = NULL;
static gpointer about_geolocation_parent_class = NULL;
static gpointer about_redirects_parent_class = NULL;
static gpointer about_manager_parent_class = NULL;

GType about_page_get_type (void) G_GNUC_CONST;
void about_page_get_contents (AboutPage* self, MidoriView* view, const gchar* uri);
static void about_page_real_get_contents (AboutPage* self, MidoriView* view, const gchar* uri);
void about_page_load_html (AboutPage* self, MidoriView* view, const gchar* content, const gchar* uri);
AboutPage* about_page_construct (GType object_type);
const gchar* about_page_get_uri (AboutPage* self);
void about_page_set_uri (AboutPage* self, const gchar* value);
static void _vala_about_page_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_about_page_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType about_widgets_get_type (void) G_GNUC_CONST;
#define ABOUT_WIDGETS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), ABOUT_TYPE_WIDGETS, AboutWidgetsPrivate))
static void about_widgets_real_get_contents (AboutPage* base, MidoriView* view, const gchar* uri);
AboutWidgets* about_widgets_new (void);
AboutWidgets* about_widgets_construct (GType object_type);
static void about_widgets_finalize (GObject * obj);
static void _vala_about_widgets_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_about_widgets_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType about_version_get_type (void) G_GNUC_CONST;
#define ABOUT_VERSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), ABOUT_TYPE_VERSION, AboutVersionPrivate))
AboutVersion* about_version_new (const gchar* alias, GHashTable* about_pages);
AboutVersion* about_version_construct (GType object_type, const gchar* alias, GHashTable* about_pages);
static gchar* about_version_list_about_uris (AboutVersion* self);
static void about_version_real_get_contents (AboutPage* base, MidoriView* view, const gchar* uri);
static void about_version_finalize (GObject * obj);
static void _vala_about_version_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_about_version_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType about_private_get_type (void) G_GNUC_CONST;
#define ABOUT_PRIVATE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), ABOUT_TYPE_PRIVATE, AboutPrivatePrivate))
static void about_private_real_get_contents (AboutPage* base, MidoriView* view, const gchar* uri);
AboutPrivate* about_private_new (void);
AboutPrivate* about_private_construct (GType object_type);
static void about_private_finalize (GObject * obj);
static void _vala_about_private_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_about_private_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType about_paths_get_type (void) G_GNUC_CONST;
#define ABOUT_PATHS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), ABOUT_TYPE_PATHS, AboutPathsPrivate))
static void about_paths_real_get_contents (AboutPage* base, MidoriView* view, const gchar* uri);
AboutPaths* about_paths_new (void);
AboutPaths* about_paths_construct (GType object_type);
static void about_paths_finalize (GObject * obj);
static void _vala_about_paths_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_about_paths_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType about_dial_get_type (void) G_GNUC_CONST;
#define ABOUT_DIAL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), ABOUT_TYPE_DIAL, AboutDialPrivate))
static void about_dial_real_get_contents (AboutPage* base, MidoriView* view, const gchar* uri);
AboutDial* about_dial_new (void);
AboutDial* about_dial_construct (GType object_type);
static void about_dial_finalize (GObject * obj);
static void _vala_about_dial_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_about_dial_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType about_geolocation_get_type (void) G_GNUC_CONST;
#define ABOUT_GEOLOCATION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), ABOUT_TYPE_GEOLOCATION, AboutGeolocationPrivate))
static void about_geolocation_real_get_contents (AboutPage* base, MidoriView* view, const gchar* uri);
AboutGeolocation* about_geolocation_new (void);
AboutGeolocation* about_geolocation_construct (GType object_type);
static void about_geolocation_finalize (GObject * obj);
static void _vala_about_geolocation_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_about_geolocation_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType about_redirects_get_type (void) G_GNUC_CONST;
#define ABOUT_REDIRECTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), ABOUT_TYPE_REDIRECTS, AboutRedirectsPrivate))
AboutRedirects* about_redirects_new (const gchar* alias, const gchar* property);
AboutRedirects* about_redirects_construct (GType object_type, const gchar* alias, const gchar* property);
static void about_redirects_real_get_contents (AboutPage* base, MidoriView* view, const gchar* uri);
static void about_redirects_finalize (GObject * obj);
static void _vala_about_redirects_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_about_redirects_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType about_manager_get_type (void) G_GNUC_CONST;
#define ABOUT_MANAGER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), ABOUT_TYPE_MANAGER, AboutManagerPrivate))
static void about_manager_register (AboutManager* self, AboutPage* page);
static gboolean about_manager_about_content (AboutManager* self, MidoriView* view, const gchar* uri);
static void about_manager_tab_added (AboutManager* self, MidoriBrowser* browser, MidoriView* view);
static gboolean _about_manager_about_content_midori_view_about_content (MidoriView* _sender, const gchar* uri, gpointer self);
static void about_manager_tab_removed (AboutManager* self, MidoriBrowser* browser, MidoriView* view);
static void about_manager_browser_added (AboutManager* self, MidoriBrowser* browser);
static void _about_manager_tab_added_midori_browser_add_tab (MidoriBrowser* _sender, MidoriView* tab, gpointer self);
static void _about_manager_tab_removed_midori_browser_remove_tab (MidoriBrowser* _sender, MidoriView* tab, gpointer self);
static void about_manager_browser_removed (AboutManager* self, MidoriBrowser* browser);
void about_manager_activated (AboutManager* self, MidoriApp* app);
static void _g_free0_ (gpointer var);
static void _g_object_unref0_ (gpointer var);
static void _about_manager_browser_added_midori_app_add_browser (MidoriApp* _sender, MidoriBrowser* browser, gpointer self);
void about_manager_deactivated (AboutManager* self);
AboutManager* about_manager_new (void);
AboutManager* about_manager_construct (GType object_type);
static void _about_manager_activated_midori_extension_activate (MidoriExtension* _sender, MidoriApp* app, gpointer self);
static void _about_manager_deactivated_midori_extension_deactivate (MidoriExtension* _sender, gpointer self);
static void about_manager_finalize (GObject * obj);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


static void about_page_real_get_contents (AboutPage* self, MidoriView* view, const gchar* uri) {
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_critical ("Type `%s' does not implement abstract method `about_page_get_contents'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	return;
#line 416 "about.c"
}


void about_page_get_contents (AboutPage* self, MidoriView* view, const gchar* uri) {
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (self != NULL);
#line 16 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	ABOUT_PAGE_GET_CLASS (self)->get_contents (self, view, uri);
#line 425 "about.c"
}


void about_page_load_html (AboutPage* self, MidoriView* view, const gchar* content, const gchar* uri) {
	MidoriView* _tmp0_;
	WebKitWebView* _tmp1_;
	WebKitWebView* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
#line 17 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (self != NULL);
#line 17 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (view != NULL);
#line 17 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (content != NULL);
#line 17 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (uri != NULL);
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp0_ = view;
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp1_ = midori_tab_get_web_view ((MidoriTab*) _tmp0_);
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp2_ = _tmp1_;
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp3_ = content;
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp4_ = uri;
#line 21 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	webkit_web_view_load_html_string (_tmp2_, _tmp3_, _tmp4_);
#line 455 "about.c"
}


AboutPage* about_page_construct (GType object_type) {
	AboutPage * self = NULL;
#line 14 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = (AboutPage*) g_object_new (object_type, NULL);
#line 14 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	return self;
#line 465 "about.c"
}


const gchar* about_page_get_uri (AboutPage* self) {
#line 15 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 15 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	return ABOUT_PAGE_GET_CLASS (self)->get_uri (self);
#line 474 "about.c"
}


void about_page_set_uri (AboutPage* self, const gchar* value) {
#line 15 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (self != NULL);
#line 15 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	ABOUT_PAGE_GET_CLASS (self)->set_uri (self, value);
#line 483 "about.c"
}


static void about_page_class_init (AboutPageClass * klass) {
#line 14 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	about_page_parent_class = g_type_class_peek_parent (klass);
#line 14 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	((AboutPageClass *) klass)->get_contents = (void (*) (AboutPage *, MidoriView*, const gchar*)) about_page_real_get_contents;
#line 14 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_about_page_get_property;
#line 14 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_about_page_set_property;
#line 14 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), ABOUT_PAGE_URI_PROPERTY, about_page_properties[ABOUT_PAGE_URI_PROPERTY] = g_param_spec_string ("uri", "uri", "uri", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 498 "about.c"
}


static void about_page_instance_init (AboutPage * self) {
}


GType about_page_get_type (void) {
	static volatile gsize about_page_type_id__volatile = 0;
	if (g_once_init_enter (&about_page_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AboutPageClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) about_page_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AboutPage), 0, (GInstanceInitFunc) about_page_instance_init, NULL };
		GType about_page_type_id;
		about_page_type_id = g_type_register_static (G_TYPE_OBJECT, "AboutPage", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_once_init_leave (&about_page_type_id__volatile, about_page_type_id);
	}
	return about_page_type_id__volatile;
}


static void _vala_about_page_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	AboutPage * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, ABOUT_TYPE_PAGE, AboutPage);
#line 14 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	switch (property_id) {
#line 523 "about.c"
		default:
#line 14 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 14 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		break;
#line 529 "about.c"
	}
}


static void _vala_about_page_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	AboutPage * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, ABOUT_TYPE_PAGE, AboutPage);
#line 14 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	switch (property_id) {
#line 539 "about.c"
		default:
#line 14 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 14 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		break;
#line 545 "about.c"
	}
}


static void about_widgets_real_get_contents (AboutPage* base, MidoriView* view, const gchar* uri) {
	AboutWidgets * self;
	gchar** widgets = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	gchar* _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	gchar* _tmp20_;
	gchar* _tmp21_;
	gchar** _tmp22_;
	gint widgets_length1;
	gint _widgets_size_;
	gchar* content = NULL;
	gchar* _tmp23_;
	gchar** widget_options = NULL;
	gchar* _tmp24_;
	gchar* _tmp25_;
	gchar* _tmp26_;
	gchar** _tmp27_;
	gint widget_options_length1;
	gint _widget_options_size_;
	gchar** widgets_formated = NULL;
	gchar* _tmp28_;
	gchar* _tmp29_;
	gchar* _tmp30_;
	gchar** _tmp31_;
	gint widgets_formated_length1;
	gint _widgets_formated_size_;
	MidoriView* _tmp58_;
	const gchar* _tmp59_;
	const gchar* _tmp60_;
	const gchar* _tmp61_;
	gchar** _tmp62_;
	gint _tmp62__length1;
	const gchar* _tmp63_;
	gchar** _tmp64_;
	gint _tmp64__length1;
	const gchar* _tmp65_;
	gchar** _tmp66_;
	gint _tmp66__length1;
	const gchar* _tmp67_;
	gchar* _tmp68_;
	gchar* _tmp69_;
	const gchar* _tmp70_;
#line 28 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = (AboutWidgets*) base;
#line 28 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (view != NULL);
#line 28 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (uri != NULL);
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp0_ = g_strdup ("<input value=\"demo\"%s>");
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp1_ = g_strdup ("<p><input type=\"password\" value=\"demo\"%s></p>");
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp2_ = g_strdup ("<p><input type=\"checkbox\" value=\"demo\"%s> demo</p>");
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp3_ = g_strdup ("<p><input type=\"radio\" value=\"demo\"%s> demo</p>");
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp4_ = g_strdup ("<p><select%s><option>foo bar</option><option selected>spam eggs</optio" \
"n></select></p>");
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp5_ = g_strdup ("<p><select%s size=\"3\"><option>foo bar</option><option selected>spam " \
"eggs</option></select></p>");
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp6_ = g_strdup ("<p><input type=\"file\"%s></p>");
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp7_ = g_strdup ("<p><input type=\"file\" multiple%s></p>");
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp8_ = g_strdup ("<input type=\"button\" value=\"demo\"%s>");
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp9_ = g_strdup ("<p><input type=\"email\" value=\"user@localhost.com\"%s></p>");
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp10_ = g_strdup ("<input type=\"url\" value=\"http://www.example.com\"%s>");
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp11_ = g_strdup ("<input type=\"tel\" value=\"+1 234 567 890\" pattern=\"^[0+][1-9 /-]*$" \
"\"%s>");
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp12_ = g_strdup ("<input type=\"number\" min=1 max=9 step=1 value=\"4\"%s>");
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp13_ = g_strdup ("<input type=\"range\" min=1 max=9 step=1 value=\"4\"%s>");
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp14_ = g_strdup ("<input type=\"date\" min=1990-01-01 max=2010-01-01%s>");
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp15_ = g_strdup ("<input type=\"search\" placeholder=\"demo\"%s>");
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp16_ = g_strdup ("<textarea%s>Lorem ipsum doloret sit amet…</textarea>");
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp17_ = g_strdup ("<input type=\"color\" value=\"#d1eeb9\"%s>");
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp18_ = g_strdup ("<progress min=1 max=9 value=4 %s></progress>");
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp19_ = g_strdup ("<keygen type=\"rsa\" challenge=\"235ldahlae983dadfar\"%s>");
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp20_ = g_strdup ("<p><input type=\"reset\"%s></p>");
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp21_ = g_strdup ("<input type=\"submit\"%s>");
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp22_ = g_new0 (gchar*, 22 + 1);
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp22_[0] = _tmp0_;
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp22_[1] = _tmp1_;
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp22_[2] = _tmp2_;
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp22_[3] = _tmp3_;
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp22_[4] = _tmp4_;
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp22_[5] = _tmp5_;
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp22_[6] = _tmp6_;
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp22_[7] = _tmp7_;
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp22_[8] = _tmp8_;
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp22_[9] = _tmp9_;
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp22_[10] = _tmp10_;
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp22_[11] = _tmp11_;
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp22_[12] = _tmp12_;
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp22_[13] = _tmp13_;
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp22_[14] = _tmp14_;
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp22_[15] = _tmp15_;
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp22_[16] = _tmp16_;
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp22_[17] = _tmp17_;
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp22_[18] = _tmp18_;
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp22_[19] = _tmp19_;
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp22_[20] = _tmp20_;
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp22_[21] = _tmp21_;
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	widgets = _tmp22_;
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	widgets_length1 = 22;
#line 29 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_widgets_size_ = widgets_length1;
#line 54 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp23_ = g_strdup ("<html>\n" \
"                <head>\n" \
"                    <style>\n" \
"                        .fallback::-webkit-slider-thumb,\n" \
"                        .fallback, .fallback::-webkit-file-upload-butt" \
"on {\n" \
"                            -webkit-appearance: none !important;\n" \
"                        }\n" \
"                        .column {\n" \
"                            display:inline-block; vertical-align:top;\n" \
"                            width:25%;\n" \
"                            margin-right:1%;\n" \
"                        }\n" \
"                    </style>\n" \
"                    <title>%s</title>\n" \
"                </head>\n" \
"                <body>\n" \
"                    <h1>%s</h1>\n" \
"                    <div class=\"column\">%s</div>\n" \
"                    <div class=\"column\">%s</div>\n" \
"                    <div class=\"column\">%s</div>\n" \
"                    <p><a href=\"http://example.com\" target=\"wp\" on" \
"click=\"javascript:window.open('http://example.com','wp','width=320, h" \
"eight=240, toolbar=false'); return false;\">Popup window</a></p>\n" \
"                </body>\n" \
"            </html>");
#line 54 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	content = _tmp23_;
#line 78 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp24_ = g_strdup ("");
#line 78 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp25_ = g_strdup (" disabled");
#line 78 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp26_ = g_strdup (" class=\"fallback\"");
#line 78 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp27_ = g_new0 (gchar*, 3 + 1);
#line 78 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp27_[0] = _tmp24_;
#line 78 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp27_[1] = _tmp25_;
#line 78 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp27_[2] = _tmp26_;
#line 78 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	widget_options = _tmp27_;
#line 78 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	widget_options_length1 = 3;
#line 78 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_widget_options_size_ = widget_options_length1;
#line 79 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp28_ = g_strdup ("");
#line 79 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp29_ = g_strdup ("");
#line 79 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp30_ = g_strdup ("");
#line 79 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp31_ = g_new0 (gchar*, 3 + 1);
#line 79 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp31_[0] = _tmp28_;
#line 79 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp31_[1] = _tmp29_;
#line 79 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp31_[2] = _tmp30_;
#line 79 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	widgets_formated = _tmp31_;
#line 79 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	widgets_formated_length1 = 3;
#line 79 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_widgets_formated_size_ = widgets_formated_length1;
#line 756 "about.c"
	{
		gint i = 0;
#line 81 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		i = 0;
#line 761 "about.c"
		{
			gboolean _tmp32_ = FALSE;
#line 81 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
			_tmp32_ = TRUE;
#line 81 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
			while (TRUE) {
#line 768 "about.c"
				gboolean _tmp34_ = FALSE;
				gint _tmp35_;
				gchar** _tmp36_;
				gint _tmp36__length1;
#line 81 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
				if (!_tmp32_) {
#line 775 "about.c"
					gint _tmp33_;
#line 81 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
					_tmp33_ = i;
#line 81 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
					i = _tmp33_ + 1;
#line 781 "about.c"
				}
#line 81 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
				_tmp32_ = FALSE;
#line 81 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
				_tmp35_ = i;
#line 81 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
				_tmp36_ = widget_options;
#line 81 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
				_tmp36__length1 = widget_options_length1;
#line 81 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
				if (_tmp35_ < _tmp36__length1) {
#line 793 "about.c"
					gint _tmp37_;
					gchar** _tmp38_;
					gint _tmp38__length1;
#line 81 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
					_tmp37_ = i;
#line 81 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
					_tmp38_ = widgets_formated;
#line 81 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
					_tmp38__length1 = widgets_formated_length1;
#line 81 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
					_tmp34_ = _tmp37_ < _tmp38__length1;
#line 805 "about.c"
				} else {
#line 81 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
					_tmp34_ = FALSE;
#line 809 "about.c"
				}
#line 81 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
				if (!_tmp34_) {
#line 81 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
					break;
#line 815 "about.c"
				}
				{
					gint j = 0;
#line 82 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
					j = 0;
#line 821 "about.c"
					{
						gboolean _tmp39_ = FALSE;
#line 82 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
						_tmp39_ = TRUE;
#line 82 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
						while (TRUE) {
#line 828 "about.c"
							gint _tmp41_;
							gchar** _tmp42_;
							gint _tmp42__length1;
							gchar** _tmp43_;
							gint _tmp43__length1;
							gint _tmp44_;
							gchar** _tmp45_;
							gint _tmp45__length1;
							gint _tmp46_;
							const gchar* _tmp47_;
							gchar** _tmp48_;
							gint _tmp48__length1;
							gint _tmp49_;
							const gchar* _tmp50_;
							gchar** _tmp51_;
							gint _tmp51__length1;
							gint _tmp52_;
							const gchar* _tmp53_;
							gchar* _tmp54_;
							gchar* _tmp55_;
							gchar* _tmp56_;
							gchar* _tmp57_;
#line 82 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
							if (!_tmp39_) {
#line 853 "about.c"
								gint _tmp40_;
#line 82 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
								_tmp40_ = j;
#line 82 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
								j = _tmp40_ + 1;
#line 859 "about.c"
							}
#line 82 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
							_tmp39_ = FALSE;
#line 82 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
							_tmp41_ = j;
#line 82 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
							_tmp42_ = widgets;
#line 82 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
							_tmp42__length1 = widgets_length1;
#line 82 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
							if (!(_tmp41_ < _tmp42__length1)) {
#line 82 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
								break;
#line 873 "about.c"
							}
#line 83 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
							_tmp43_ = widgets_formated;
#line 83 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
							_tmp43__length1 = widgets_formated_length1;
#line 83 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
							_tmp44_ = i;
#line 83 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
							_tmp45_ = widgets_formated;
#line 83 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
							_tmp45__length1 = widgets_formated_length1;
#line 83 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
							_tmp46_ = i;
#line 83 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
							_tmp47_ = _tmp45_[_tmp46_];
#line 83 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
							_tmp48_ = widgets;
#line 83 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
							_tmp48__length1 = widgets_length1;
#line 83 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
							_tmp49_ = j;
#line 83 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
							_tmp50_ = _tmp48_[_tmp49_];
#line 83 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
							_tmp51_ = widget_options;
#line 83 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
							_tmp51__length1 = widget_options_length1;
#line 83 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
							_tmp52_ = i;
#line 83 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
							_tmp53_ = _tmp51_[_tmp52_];
#line 83 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
							_tmp54_ = g_strdup_printf (_tmp50_, _tmp53_);
#line 83 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
							_tmp55_ = _tmp54_;
#line 83 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
							_tmp56_ = g_strconcat (_tmp47_, _tmp55_, NULL);
#line 83 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
							_g_free0 (_tmp43_[_tmp44_]);
#line 83 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
							_tmp43_[_tmp44_] = _tmp56_;
#line 83 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
							_tmp57_ = _tmp43_[_tmp44_];
#line 83 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
							_g_free0 (_tmp55_);
#line 919 "about.c"
						}
					}
				}
			}
		}
	}
#line 87 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp58_ = view;
#line 87 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp59_ = content;
#line 87 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp60_ = uri;
#line 87 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp61_ = uri;
#line 87 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp62_ = widgets_formated;
#line 87 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp62__length1 = widgets_formated_length1;
#line 87 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp63_ = _tmp62_[0];
#line 87 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp64_ = widgets_formated;
#line 87 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp64__length1 = widgets_formated_length1;
#line 87 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp65_ = _tmp64_[1];
#line 87 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp66_ = widgets_formated;
#line 87 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp66__length1 = widgets_formated_length1;
#line 87 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp67_ = _tmp66_[2];
#line 87 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp68_ = g_strdup_printf (_tmp59_, _tmp60_, _tmp61_, _tmp63_, _tmp65_, _tmp67_);
#line 87 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp69_ = _tmp68_;
#line 87 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp70_ = uri;
#line 87 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	about_page_load_html ((AboutPage*) self, _tmp58_, _tmp69_, _tmp70_);
#line 87 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_free0 (_tmp69_);
#line 28 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	widgets_formated = (_vala_array_free (widgets_formated, widgets_formated_length1, (GDestroyNotify) g_free), NULL);
#line 28 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	widget_options = (_vala_array_free (widget_options, widget_options_length1, (GDestroyNotify) g_free), NULL);
#line 28 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_free0 (content);
#line 28 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	widgets = (_vala_array_free (widgets, widgets_length1, (GDestroyNotify) g_free), NULL);
#line 970 "about.c"
}


AboutWidgets* about_widgets_construct (GType object_type) {
	AboutWidgets * self = NULL;
#line 26 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = (AboutWidgets*) about_page_construct (object_type);
#line 26 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	return self;
#line 980 "about.c"
}


AboutWidgets* about_widgets_new (void) {
#line 26 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	return about_widgets_construct (ABOUT_TYPE_WIDGETS);
#line 987 "about.c"
}


static const gchar* about_widgets_real_get_uri (AboutPage* base) {
	const gchar* result;
	AboutWidgets* self;
	const gchar* _tmp0_;
#line 27 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = (AboutWidgets*) base;
#line 27 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp0_ = self->priv->_uri;
#line 27 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	result = _tmp0_;
#line 27 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	return result;
#line 1003 "about.c"
}


static void about_widgets_real_set_uri (AboutPage* base, const gchar* value) {
	AboutWidgets* self;
#line 27 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = (AboutWidgets*) base;
#line 27 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	if (g_strcmp0 (value, about_widgets_real_get_uri (base)) != 0) {
#line 1013 "about.c"
		const gchar* _tmp0_;
		gchar* _tmp1_;
#line 27 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_tmp0_ = value;
#line 27 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_tmp1_ = g_strdup (_tmp0_);
#line 27 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_g_free0 (self->priv->_uri);
#line 27 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		self->priv->_uri = _tmp1_;
#line 27 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		g_object_notify_by_pspec ((GObject *) self, about_widgets_properties[ABOUT_WIDGETS_URI_PROPERTY]);
#line 1026 "about.c"
	}
}


static void about_widgets_class_init (AboutWidgetsClass * klass) {
#line 26 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	about_widgets_parent_class = g_type_class_peek_parent (klass);
#line 26 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_type_class_add_private (klass, sizeof (AboutWidgetsPrivate));
#line 26 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	((AboutPageClass *) klass)->get_contents = (void (*) (AboutPage *, MidoriView*, const gchar*)) about_widgets_real_get_contents;
#line 26 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	ABOUT_PAGE_CLASS (klass)->get_uri = about_widgets_real_get_uri;
#line 26 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	ABOUT_PAGE_CLASS (klass)->set_uri = about_widgets_real_set_uri;
#line 26 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_about_widgets_get_property;
#line 26 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_about_widgets_set_property;
#line 26 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	G_OBJECT_CLASS (klass)->finalize = about_widgets_finalize;
#line 26 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), ABOUT_WIDGETS_URI_PROPERTY, about_widgets_properties[ABOUT_WIDGETS_URI_PROPERTY] = g_param_spec_string ("uri", "uri", "uri", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 1050 "about.c"
}


static void about_widgets_instance_init (AboutWidgets * self) {
	gchar* _tmp0_;
#line 26 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self->priv = ABOUT_WIDGETS_GET_PRIVATE (self);
#line 27 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp0_ = g_strdup ("about:widgets");
#line 27 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self->priv->_uri = _tmp0_;
#line 1062 "about.c"
}


static void about_widgets_finalize (GObject * obj) {
	AboutWidgets * self;
#line 26 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, ABOUT_TYPE_WIDGETS, AboutWidgets);
#line 27 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_free0 (self->priv->_uri);
#line 26 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	G_OBJECT_CLASS (about_widgets_parent_class)->finalize (obj);
#line 1074 "about.c"
}


GType about_widgets_get_type (void) {
	static volatile gsize about_widgets_type_id__volatile = 0;
	if (g_once_init_enter (&about_widgets_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AboutWidgetsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) about_widgets_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AboutWidgets), 0, (GInstanceInitFunc) about_widgets_instance_init, NULL };
		GType about_widgets_type_id;
		about_widgets_type_id = g_type_register_static (ABOUT_TYPE_PAGE, "AboutWidgets", &g_define_type_info, 0);
		g_once_init_leave (&about_widgets_type_id__volatile, about_widgets_type_id);
	}
	return about_widgets_type_id__volatile;
}


static void _vala_about_widgets_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	AboutWidgets * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, ABOUT_TYPE_WIDGETS, AboutWidgets);
#line 26 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	switch (property_id) {
#line 26 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		case ABOUT_WIDGETS_URI_PROPERTY:
#line 26 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		g_value_set_string (value, about_page_get_uri ((AboutPage*) self));
#line 26 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		break;
#line 1101 "about.c"
		default:
#line 26 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 26 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		break;
#line 1107 "about.c"
	}
}


static void _vala_about_widgets_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	AboutWidgets * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, ABOUT_TYPE_WIDGETS, AboutWidgets);
#line 26 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	switch (property_id) {
#line 26 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		case ABOUT_WIDGETS_URI_PROPERTY:
#line 26 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		about_page_set_uri ((AboutPage*) self, g_value_get_string (value));
#line 26 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		break;
#line 1123 "about.c"
		default:
#line 26 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 26 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		break;
#line 1129 "about.c"
	}
}


static gpointer _g_hash_table_ref0 (gpointer self) {
#line 97 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	return self ? g_hash_table_ref (self) : NULL;
#line 1137 "about.c"
}


AboutVersion* about_version_construct (GType object_type, const gchar* alias, GHashTable* about_pages) {
	AboutVersion * self = NULL;
	const gchar* _tmp0_;
	GHashTable* _tmp1_;
	GHashTable* _tmp2_;
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_val_if_fail (alias != NULL, NULL);
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_val_if_fail (about_pages != NULL, NULL);
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = (AboutVersion*) about_page_construct (object_type);
#line 96 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp0_ = alias;
#line 96 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	about_page_set_uri ((AboutPage*) self, _tmp0_);
#line 97 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp1_ = about_pages;
#line 97 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp2_ = _g_hash_table_ref0 (_tmp1_);
#line 97 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_hash_table_unref0 (self->priv->about_pages);
#line 97 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self->priv->about_pages = _tmp2_;
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	return self;
#line 1166 "about.c"
}


AboutVersion* about_version_new (const gchar* alias, GHashTable* about_pages) {
#line 95 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	return about_version_construct (ABOUT_TYPE_VERSION, alias, about_pages);
#line 1173 "about.c"
}


static gchar* about_version_list_about_uris (AboutVersion* self) {
	gchar* result = NULL;
	gchar* links = NULL;
	gchar* _tmp0_;
	GHashTable* _tmp1_;
	GList* _tmp2_;
	const gchar* _tmp9_;
	gchar* _tmp10_;
#line 100 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 101 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp0_ = g_strdup ("");
#line 101 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	links = _tmp0_;
#line 102 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp1_ = self->priv->about_pages;
#line 102 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp2_ = g_hash_table_get_keys (_tmp1_);
#line 1195 "about.c"
	{
		GList* uri_collection = NULL;
		GList* uri_it = NULL;
#line 102 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		uri_collection = _tmp2_;
#line 102 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		for (uri_it = uri_collection; uri_it != NULL; uri_it = uri_it->next) {
#line 1203 "about.c"
			const gchar* uri = NULL;
#line 102 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
			uri = (const gchar*) uri_it->data;
#line 1207 "about.c"
			{
				const gchar* _tmp3_;
				const gchar* _tmp4_;
				const gchar* _tmp5_;
				gchar* _tmp6_;
				gchar* _tmp7_;
				gchar* _tmp8_;
#line 103 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
				_tmp3_ = links;
#line 103 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
				_tmp4_ = uri;
#line 103 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
				_tmp5_ = uri;
#line 103 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
				_tmp6_ = g_strdup_printf ("<a href=\"%s\">%s</a> &nbsp;", _tmp4_, _tmp5_);
#line 103 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
				_tmp7_ = _tmp6_;
#line 103 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
				_tmp8_ = g_strconcat (_tmp3_, _tmp7_, NULL);
#line 103 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
				_g_free0 (links);
#line 103 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
				links = _tmp8_;
#line 103 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
				_g_free0 (_tmp7_);
#line 1233 "about.c"
			}
		}
#line 102 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_g_list_free0 (uri_collection);
#line 1238 "about.c"
	}
#line 104 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp9_ = links;
#line 104 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp10_ = g_strdup_printf ("<p>%s</p>", _tmp9_);
#line 104 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	result = _tmp10_;
#line 104 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_free0 (links);
#line 104 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	return result;
#line 1250 "about.c"
}


static void about_version_real_get_contents (AboutPage* base, MidoriView* view, const gchar* uri) {
	AboutVersion * self;
	gchar* contents = NULL;
	gchar* _tmp0_;
	GString* versions = NULL;
	GString* _tmp1_;
	GString* _tmp2_;
	gchar* ident = NULL;
	const gchar* architecture = NULL;
	const gchar* platform = NULL;
	const gchar* sys_name = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_;
	MidoriView* _tmp6_;
	MidoriWebSettings* _tmp7_;
	MidoriWebSettings* _tmp8_;
	MidoriWebSettings* _tmp9_;
	GString* video_formats = NULL;
	GString* _tmp10_;
	MidoriView* _tmp11_;
	GString* _tmp12_;
	GString* ns_plugins = NULL;
	GString* _tmp13_;
	MidoriView* _tmp14_;
	GString* _tmp15_;
	const gchar* _tmp16_ = NULL;
	const gchar* _tmp17_;
	MidoriView* _tmp19_;
	const gchar* _tmp20_;
	gchar* _tmp21_;
	gchar* _tmp22_;
	GString* _tmp23_;
	const gchar* _tmp24_;
	const gchar* _tmp25_;
	const gchar* _tmp26_;
	const gchar* _tmp27_;
	GString* _tmp28_;
	const gchar* _tmp29_;
	GString* _tmp30_;
	const gchar* _tmp31_;
	gchar* _tmp32_;
	gchar* _tmp33_;
	gchar* _tmp34_;
	gchar* _tmp35_;
	const gchar* _tmp36_;
#line 107 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = (AboutVersion*) base;
#line 107 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (view != NULL);
#line 107 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (uri != NULL);
#line 108 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp0_ = g_strdup ("<html>\n" \
"                <head><title>about:version</title></head>\n" \
"                <body>\n" \
"                    <h1>a<span style=\"position: absolute; left: -1000" \
"px; top: -1000px\">lias a=b; echo Copy carefully #</span>bout:version<" \
"/h1>\n" \
"                    <p>%s</p>\n" \
"                    <img src=\"res://logo-shade.png\" style=\"position" \
": absolute; right: 15px; bottom: 15px; z-index: -9;\">\n" \
"                    <table>\n" \
"                        <tr><td>Command line %s</td></tr>\n" \
"                        %s\n" \
"                        <tr><td>Platform %s %s %s</td></tr>\n" \
"                        <tr><td>Identification %s</td></tr>\n" \
"                        %s\n" \
"                    </table>\n" \
"                    <table>\n" \
"                        %s\n" \
"                    </table>\n" \
"                    %s\n" \
"                </body>\n" \
"            </html>");
#line 108 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	contents = _tmp0_;
#line 128 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp1_ = g_string_new ("");
#line 128 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	versions = _tmp1_;
#line 129 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp2_ = versions;
#line 129 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	midori_view_list_versions (_tmp2_, TRUE);
#line 134 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp5_ = midori_web_settings_get_system_name (&_tmp3_, &_tmp4_);
#line 134 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	architecture = _tmp3_;
#line 134 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	platform = _tmp4_;
#line 134 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	sys_name = _tmp5_;
#line 135 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp6_ = view;
#line 135 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_object_get (_tmp6_, "settings", &_tmp7_, NULL);
#line 135 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp8_ = _tmp7_;
#line 135 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp9_ = _tmp8_;
#line 135 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_object_get ((GObject*) _tmp9_, "user-agent", &ident, NULL);
#line 135 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_object_unref0 (_tmp9_);
#line 137 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp10_ = g_string_new ("");
#line 137 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	video_formats = _tmp10_;
#line 138 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp11_ = view;
#line 138 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp12_ = video_formats;
#line 138 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	midori_view_list_video_formats (_tmp11_, _tmp12_, TRUE);
#line 140 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp13_ = g_string_new ("");
#line 140 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	ns_plugins = _tmp13_;
#line 141 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp14_ = view;
#line 141 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp15_ = ns_plugins;
#line 141 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	midori_view_list_plugins (_tmp14_, _tmp15_, TRUE);
#line 149 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp17_ = architecture;
#line 149 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	if (_tmp17_ != NULL) {
#line 1362 "about.c"
		const gchar* _tmp18_;
#line 149 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_tmp18_ = architecture;
#line 149 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_tmp16_ = _tmp18_;
#line 1368 "about.c"
	} else {
#line 149 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_tmp16_ = "";
#line 1372 "about.c"
	}
#line 145 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp19_ = view;
#line 145 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp20_ = contents;
#line 145 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp21_ = midori_paths_get_command_line_str (TRUE);
#line 145 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp22_ = _tmp21_;
#line 145 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp23_ = versions;
#line 145 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp24_ = _tmp23_->str;
#line 145 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp25_ = platform;
#line 145 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp26_ = sys_name;
#line 145 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp27_ = ident;
#line 145 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp28_ = video_formats;
#line 145 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp29_ = _tmp28_->str;
#line 145 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp30_ = ns_plugins;
#line 145 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp31_ = _tmp30_->str;
#line 145 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp32_ = about_version_list_about_uris (self);
#line 145 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp33_ = _tmp32_;
#line 145 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp34_ = g_strdup_printf (_tmp20_, _ ("Version numbers in brackets show the version used at runtime."), _tmp22_, _tmp24_, _tmp25_, _tmp26_, _tmp16_, _tmp27_, _tmp29_, _tmp31_, _tmp33_);
#line 145 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp35_ = _tmp34_;
#line 145 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp36_ = uri;
#line 145 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	about_page_load_html ((AboutPage*) self, _tmp19_, _tmp35_, _tmp36_);
#line 145 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_free0 (_tmp35_);
#line 145 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_free0 (_tmp33_);
#line 145 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_free0 (_tmp22_);
#line 107 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_string_free0 (ns_plugins);
#line 107 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_string_free0 (video_formats);
#line 107 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_free0 (ident);
#line 107 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_string_free0 (versions);
#line 107 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_free0 (contents);
#line 1428 "about.c"
}


static const gchar* about_version_real_get_uri (AboutPage* base) {
	const gchar* result;
	AboutVersion* self;
	const gchar* _tmp0_;
#line 92 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = (AboutVersion*) base;
#line 92 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp0_ = self->priv->_uri;
#line 92 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	result = _tmp0_;
#line 92 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	return result;
#line 1444 "about.c"
}


static void about_version_real_set_uri (AboutPage* base, const gchar* value) {
	AboutVersion* self;
#line 92 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = (AboutVersion*) base;
#line 92 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	if (g_strcmp0 (value, about_version_real_get_uri (base)) != 0) {
#line 1454 "about.c"
		const gchar* _tmp0_;
		gchar* _tmp1_;
#line 92 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_tmp0_ = value;
#line 92 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_tmp1_ = g_strdup (_tmp0_);
#line 92 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_g_free0 (self->priv->_uri);
#line 92 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		self->priv->_uri = _tmp1_;
#line 92 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		g_object_notify_by_pspec ((GObject *) self, about_version_properties[ABOUT_VERSION_URI_PROPERTY]);
#line 1467 "about.c"
	}
}


static void about_version_class_init (AboutVersionClass * klass) {
#line 91 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	about_version_parent_class = g_type_class_peek_parent (klass);
#line 91 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_type_class_add_private (klass, sizeof (AboutVersionPrivate));
#line 91 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	((AboutPageClass *) klass)->get_contents = (void (*) (AboutPage *, MidoriView*, const gchar*)) about_version_real_get_contents;
#line 91 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	ABOUT_PAGE_CLASS (klass)->get_uri = about_version_real_get_uri;
#line 91 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	ABOUT_PAGE_CLASS (klass)->set_uri = about_version_real_set_uri;
#line 91 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_about_version_get_property;
#line 91 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_about_version_set_property;
#line 91 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	G_OBJECT_CLASS (klass)->finalize = about_version_finalize;
#line 91 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), ABOUT_VERSION_URI_PROPERTY, about_version_properties[ABOUT_VERSION_URI_PROPERTY] = g_param_spec_string ("uri", "uri", "uri", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 1491 "about.c"
}


static void about_version_instance_init (AboutVersion * self) {
#line 91 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self->priv = ABOUT_VERSION_GET_PRIVATE (self);
#line 1498 "about.c"
}


static void about_version_finalize (GObject * obj) {
	AboutVersion * self;
#line 91 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, ABOUT_TYPE_VERSION, AboutVersion);
#line 92 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_free0 (self->priv->_uri);
#line 93 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_hash_table_unref0 (self->priv->about_pages);
#line 91 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	G_OBJECT_CLASS (about_version_parent_class)->finalize (obj);
#line 1512 "about.c"
}


GType about_version_get_type (void) {
	static volatile gsize about_version_type_id__volatile = 0;
	if (g_once_init_enter (&about_version_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AboutVersionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) about_version_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AboutVersion), 0, (GInstanceInitFunc) about_version_instance_init, NULL };
		GType about_version_type_id;
		about_version_type_id = g_type_register_static (ABOUT_TYPE_PAGE, "AboutVersion", &g_define_type_info, 0);
		g_once_init_leave (&about_version_type_id__volatile, about_version_type_id);
	}
	return about_version_type_id__volatile;
}


static void _vala_about_version_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	AboutVersion * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, ABOUT_TYPE_VERSION, AboutVersion);
#line 91 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	switch (property_id) {
#line 91 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		case ABOUT_VERSION_URI_PROPERTY:
#line 91 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		g_value_set_string (value, about_page_get_uri ((AboutPage*) self));
#line 91 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		break;
#line 1539 "about.c"
		default:
#line 91 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 91 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		break;
#line 1545 "about.c"
	}
}


static void _vala_about_version_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	AboutVersion * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, ABOUT_TYPE_VERSION, AboutVersion);
#line 91 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	switch (property_id) {
#line 91 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		case ABOUT_VERSION_URI_PROPERTY:
#line 91 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		about_page_set_uri ((AboutPage*) self, g_value_get_string (value));
#line 91 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		break;
#line 1561 "about.c"
		default:
#line 91 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 91 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		break;
#line 1567 "about.c"
	}
}


static void about_private_real_get_contents (AboutPage* base, MidoriView* view, const gchar* uri) {
	AboutPrivate * self;
	MidoriView* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	const gchar* _tmp3_;
#line 160 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = (AboutPrivate*) base;
#line 160 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (view != NULL);
#line 160 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (uri != NULL);
#line 161 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp0_ = view;
#line 161 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp1_ = g_strdup_printf ("<html dir=\"ltr\">\n" \
"                <head>\n" \
"                    <title>%s</title>\n" \
"                    <link rel=\"stylesheet\" type=\"text/css\" href=\"" \
"res://about.css\">\n" \
"                </head>\n" \
"                <body>\n" \
"                    <img id=\"logo\" src=\"res://logo-shade.png\" />\n" \
"                    <div id=\"main\" style=\"background-image: url(sto" \
"ck://dialog/gtk-dialog-info);\">\n" \
"                    <div id=\"text\">\n" \
"                    <h1>%s</h1>\n" \
"                    <p class=\"message\">%s</p><ul class=\" suggestion" \
"s\"><li>%s</li><li>%s</li><li>%s</li></ul>\n" \
"                    <p class=\"message\">%s</p><ul class=\" suggestion" \
"s\"><li>%s</li><li>%s</li><li>%s</li><li>%s</li></ul>\n" \
"                    </div><br style=\"clear: both\"></div>\n" \
"                </body>\n" \
"            </html>", _ ("Private Browsing"), _ ("Private Browsing"), _ ("Midori doesn't store any personal data:"), _ ("No history or web cookies are being saved."), _ ("Extensions are disabled."), _ ("HTML5 storage, local database and application caches are disabled."), _ ("Midori prevents websites from tracking the user:"), _ ("Referrer URLs are stripped down to the hostname."), _ ("DNS prefetching is disabled."), _ ("The language and timezone are not revealed to websites."), _ ("Flash and other Netscape plugins cannot be listed by websites."));
#line 161 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp2_ = _tmp1_;
#line 161 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp3_ = uri;
#line 161 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	about_page_load_html ((AboutPage*) self, _tmp0_, _tmp2_, _tmp3_);
#line 161 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_free0 (_tmp2_);
#line 1596 "about.c"
}


AboutPrivate* about_private_construct (GType object_type) {
	AboutPrivate * self = NULL;
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = (AboutPrivate*) about_page_construct (object_type);
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	return self;
#line 1606 "about.c"
}


AboutPrivate* about_private_new (void) {
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	return about_private_construct (ABOUT_TYPE_PRIVATE);
#line 1613 "about.c"
}


static const gchar* about_private_real_get_uri (AboutPage* base) {
	const gchar* result;
	AboutPrivate* self;
	const gchar* _tmp0_;
#line 159 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = (AboutPrivate*) base;
#line 159 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp0_ = self->priv->_uri;
#line 159 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	result = _tmp0_;
#line 159 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	return result;
#line 1629 "about.c"
}


static void about_private_real_set_uri (AboutPage* base, const gchar* value) {
	AboutPrivate* self;
#line 159 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = (AboutPrivate*) base;
#line 159 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	if (g_strcmp0 (value, about_private_real_get_uri (base)) != 0) {
#line 1639 "about.c"
		const gchar* _tmp0_;
		gchar* _tmp1_;
#line 159 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_tmp0_ = value;
#line 159 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_tmp1_ = g_strdup (_tmp0_);
#line 159 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_g_free0 (self->priv->_uri);
#line 159 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		self->priv->_uri = _tmp1_;
#line 159 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		g_object_notify_by_pspec ((GObject *) self, about_private_properties[ABOUT_PRIVATE_URI_PROPERTY]);
#line 1652 "about.c"
	}
}


static void about_private_class_init (AboutPrivateClass * klass) {
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	about_private_parent_class = g_type_class_peek_parent (klass);
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_type_class_add_private (klass, sizeof (AboutPrivatePrivate));
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	((AboutPageClass *) klass)->get_contents = (void (*) (AboutPage *, MidoriView*, const gchar*)) about_private_real_get_contents;
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	ABOUT_PAGE_CLASS (klass)->get_uri = about_private_real_get_uri;
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	ABOUT_PAGE_CLASS (klass)->set_uri = about_private_real_set_uri;
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_about_private_get_property;
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_about_private_set_property;
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	G_OBJECT_CLASS (klass)->finalize = about_private_finalize;
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), ABOUT_PRIVATE_URI_PROPERTY, about_private_properties[ABOUT_PRIVATE_URI_PROPERTY] = g_param_spec_string ("uri", "uri", "uri", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 1676 "about.c"
}


static void about_private_instance_init (AboutPrivate * self) {
	gchar* _tmp0_;
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self->priv = ABOUT_PRIVATE_GET_PRIVATE (self);
#line 159 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp0_ = g_strdup ("about:private");
#line 159 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self->priv->_uri = _tmp0_;
#line 1688 "about.c"
}


static void about_private_finalize (GObject * obj) {
	AboutPrivate * self;
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, ABOUT_TYPE_PRIVATE, AboutPrivate);
#line 159 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_free0 (self->priv->_uri);
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	G_OBJECT_CLASS (about_private_parent_class)->finalize (obj);
#line 1700 "about.c"
}


GType about_private_get_type (void) {
	static volatile gsize about_private_type_id__volatile = 0;
	if (g_once_init_enter (&about_private_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AboutPrivateClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) about_private_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AboutPrivate), 0, (GInstanceInitFunc) about_private_instance_init, NULL };
		GType about_private_type_id;
		about_private_type_id = g_type_register_static (ABOUT_TYPE_PAGE, "AboutPrivate", &g_define_type_info, 0);
		g_once_init_leave (&about_private_type_id__volatile, about_private_type_id);
	}
	return about_private_type_id__volatile;
}


static void _vala_about_private_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	AboutPrivate * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, ABOUT_TYPE_PRIVATE, AboutPrivate);
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	switch (property_id) {
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		case ABOUT_PRIVATE_URI_PROPERTY:
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		g_value_set_string (value, about_page_get_uri ((AboutPage*) self));
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		break;
#line 1727 "about.c"
		default:
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		break;
#line 1733 "about.c"
	}
}


static void _vala_about_private_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	AboutPrivate * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, ABOUT_TYPE_PRIVATE, AboutPrivate);
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	switch (property_id) {
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		case ABOUT_PRIVATE_URI_PROPERTY:
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		about_page_set_uri ((AboutPage*) self, g_value_get_string (value));
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		break;
#line 1749 "about.c"
		default:
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 158 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		break;
#line 1755 "about.c"
	}
}


static void about_paths_real_get_contents (AboutPage* base, MidoriView* view, const gchar* uri) {
	AboutPaths * self;
	gchar* res_dir = NULL;
	gchar* _tmp0_;
	gchar* lib_dir = NULL;
	gchar* _tmp1_;
	MidoriView* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	const gchar* _tmp6_;
	const gchar* _tmp7_;
	const gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	const gchar* _tmp11_;
#line 192 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = (AboutPaths*) base;
#line 192 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (view != NULL);
#line 192 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (uri != NULL);
#line 193 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp0_ = midori_paths_get_res_filename ("about.css");
#line 193 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	res_dir = _tmp0_;
#line 194 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp1_ = midori_paths_get_lib_path (PACKAGE_NAME);
#line 194 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	lib_dir = _tmp1_;
#line 195 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp2_ = view;
#line 195 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp3_ = uri;
#line 195 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp4_ = midori_paths_get_config_dir_for_reading ();
#line 195 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp5_ = _tmp4_;
#line 195 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp6_ = midori_paths_get_user_data_dir_for_reading ();
#line 195 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp7_ = midori_paths_get_cache_dir_for_reading ();
#line 195 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp8_ = midori_paths_get_tmp_dir ();
#line 195 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp9_ = g_strdup_printf ("<html>\n" \
"                <body>\n" \
"                    <h1>%s</h1>\n" \
"                    <p>config: <code>%s</code></p>\n" \
"                    <p>res: <code>%s</code></p>\n" \
"                    <p>data: <code>%s/%s</code></p>\n" \
"                    <p>lib: <code>%s</code></p>\n" \
"                    <p>cache: <code>%s</code></p>\n" \
"                    <p>tmp: <code>%s</code></p>\n" \
"                </body>\n" \
"            </html>", _tmp3_, _tmp5_, res_dir, _tmp6_, PACKAGE_NAME, lib_dir, _tmp7_, _tmp8_);
#line 195 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp10_ = _tmp9_;
#line 195 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp11_ = uri;
#line 195 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	about_page_load_html ((AboutPage*) self, _tmp2_, _tmp10_, _tmp11_);
#line 195 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_free0 (_tmp10_);
#line 195 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_free0 (_tmp5_);
#line 192 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_free0 (lib_dir);
#line 192 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_free0 (res_dir);
#line 1820 "about.c"
}


AboutPaths* about_paths_construct (GType object_type) {
	AboutPaths * self = NULL;
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = (AboutPaths*) about_page_construct (object_type);
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	return self;
#line 1830 "about.c"
}


AboutPaths* about_paths_new (void) {
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	return about_paths_construct (ABOUT_TYPE_PATHS);
#line 1837 "about.c"
}


static const gchar* about_paths_real_get_uri (AboutPage* base) {
	const gchar* result;
	AboutPaths* self;
	const gchar* _tmp0_;
#line 191 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = (AboutPaths*) base;
#line 191 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp0_ = self->priv->_uri;
#line 191 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	result = _tmp0_;
#line 191 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	return result;
#line 1853 "about.c"
}


static void about_paths_real_set_uri (AboutPage* base, const gchar* value) {
	AboutPaths* self;
#line 191 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = (AboutPaths*) base;
#line 191 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	if (g_strcmp0 (value, about_paths_real_get_uri (base)) != 0) {
#line 1863 "about.c"
		const gchar* _tmp0_;
		gchar* _tmp1_;
#line 191 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_tmp0_ = value;
#line 191 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_tmp1_ = g_strdup (_tmp0_);
#line 191 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_g_free0 (self->priv->_uri);
#line 191 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		self->priv->_uri = _tmp1_;
#line 191 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		g_object_notify_by_pspec ((GObject *) self, about_paths_properties[ABOUT_PATHS_URI_PROPERTY]);
#line 1876 "about.c"
	}
}


static void about_paths_class_init (AboutPathsClass * klass) {
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	about_paths_parent_class = g_type_class_peek_parent (klass);
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_type_class_add_private (klass, sizeof (AboutPathsPrivate));
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	((AboutPageClass *) klass)->get_contents = (void (*) (AboutPage *, MidoriView*, const gchar*)) about_paths_real_get_contents;
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	ABOUT_PAGE_CLASS (klass)->get_uri = about_paths_real_get_uri;
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	ABOUT_PAGE_CLASS (klass)->set_uri = about_paths_real_set_uri;
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_about_paths_get_property;
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_about_paths_set_property;
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	G_OBJECT_CLASS (klass)->finalize = about_paths_finalize;
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), ABOUT_PATHS_URI_PROPERTY, about_paths_properties[ABOUT_PATHS_URI_PROPERTY] = g_param_spec_string ("uri", "uri", "uri", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 1900 "about.c"
}


static void about_paths_instance_init (AboutPaths * self) {
	gchar* _tmp0_;
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self->priv = ABOUT_PATHS_GET_PRIVATE (self);
#line 191 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp0_ = g_strdup ("about:paths");
#line 191 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self->priv->_uri = _tmp0_;
#line 1912 "about.c"
}


static void about_paths_finalize (GObject * obj) {
	AboutPaths * self;
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, ABOUT_TYPE_PATHS, AboutPaths);
#line 191 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_free0 (self->priv->_uri);
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	G_OBJECT_CLASS (about_paths_parent_class)->finalize (obj);
#line 1924 "about.c"
}


GType about_paths_get_type (void) {
	static volatile gsize about_paths_type_id__volatile = 0;
	if (g_once_init_enter (&about_paths_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AboutPathsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) about_paths_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AboutPaths), 0, (GInstanceInitFunc) about_paths_instance_init, NULL };
		GType about_paths_type_id;
		about_paths_type_id = g_type_register_static (ABOUT_TYPE_PAGE, "AboutPaths", &g_define_type_info, 0);
		g_once_init_leave (&about_paths_type_id__volatile, about_paths_type_id);
	}
	return about_paths_type_id__volatile;
}


static void _vala_about_paths_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	AboutPaths * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, ABOUT_TYPE_PATHS, AboutPaths);
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	switch (property_id) {
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		case ABOUT_PATHS_URI_PROPERTY:
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		g_value_set_string (value, about_page_get_uri ((AboutPage*) self));
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		break;
#line 1951 "about.c"
		default:
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		break;
#line 1957 "about.c"
	}
}


static void _vala_about_paths_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	AboutPaths * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, ABOUT_TYPE_PATHS, AboutPaths);
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	switch (property_id) {
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		case ABOUT_PATHS_URI_PROPERTY:
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		about_page_set_uri ((AboutPage*) self, g_value_get_string (value));
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		break;
#line 1973 "about.c"
		default:
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 190 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		break;
#line 1979 "about.c"
	}
}


static gpointer _g_object_ref0 (gpointer self) {
#line 216 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	return self ? g_object_ref (self) : NULL;
#line 1987 "about.c"
}


static void about_dial_real_get_contents (AboutPage* base, MidoriView* view, const gchar* uri) {
	AboutDial * self;
	MidoriBrowser* browser = NULL;
	MidoriView* _tmp0_;
	MidoriBrowser* _tmp1_;
	MidoriBrowser* _tmp2_;
	MidoriSpeedDial* dial = NULL;
	MidoriBrowser* _tmp3_;
	MidoriSpeedDial* _tmp4_;
	GError * _inner_error_ = NULL;
#line 215 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = (AboutDial*) base;
#line 215 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (view != NULL);
#line 215 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (uri != NULL);
#line 216 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp0_ = view;
#line 216 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp1_ = midori_browser_get_for_widget ((GtkWidget*) _tmp0_);
#line 216 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 216 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	browser = _tmp2_;
#line 218 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp3_ = browser;
#line 218 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_object_get ((GObject*) _tmp3_, "speed-dial", &dial, NULL);
#line 219 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp4_ = dial;
#line 219 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	if (_tmp4_ == NULL) {
#line 220 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_g_object_unref0 (dial);
#line 220 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_g_object_unref0 (browser);
#line 220 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		return;
#line 2029 "about.c"
	}
	{
		const gchar* _tmp5_ = NULL;
		MidoriSpeedDial* _tmp6_;
		const gchar* _tmp7_;
		MidoriView* _tmp8_;
		const gchar* _tmp9_;
#line 222 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_tmp6_ = dial;
#line 222 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_tmp7_ = midori_speed_dial_get_html (_tmp6_, &_inner_error_);
#line 222 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_tmp5_ = _tmp7_;
#line 222 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2045 "about.c"
			goto __catch0_g_error;
		}
#line 222 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_tmp8_ = view;
#line 222 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_tmp9_ = uri;
#line 222 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		about_page_load_html ((AboutPage*) self, _tmp8_, _tmp5_, _tmp9_);
#line 2054 "about.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* _error_ = NULL;
		MidoriView* _tmp10_;
		GError* _tmp11_;
		const gchar* _tmp12_;
		const gchar* _tmp13_;
#line 221 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_error_ = _inner_error_;
#line 221 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_inner_error_ = NULL;
#line 224 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_tmp10_ = view;
#line 224 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_tmp11_ = _error_;
#line 224 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_tmp12_ = _tmp11_->message;
#line 224 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_tmp13_ = uri;
#line 224 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		about_page_load_html ((AboutPage*) self, _tmp10_, _tmp12_, _tmp13_);
#line 221 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_g_error_free0 (_error_);
#line 2080 "about.c"
	}
	__finally0:
#line 221 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 221 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_g_object_unref0 (dial);
#line 221 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_g_object_unref0 (browser);
#line 221 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 221 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		g_clear_error (&_inner_error_);
#line 221 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		return;
#line 2095 "about.c"
	}
#line 215 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_object_unref0 (dial);
#line 215 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_object_unref0 (browser);
#line 2101 "about.c"
}


AboutDial* about_dial_construct (GType object_type) {
	AboutDial * self = NULL;
#line 213 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = (AboutDial*) about_page_construct (object_type);
#line 213 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	return self;
#line 2111 "about.c"
}


AboutDial* about_dial_new (void) {
#line 213 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	return about_dial_construct (ABOUT_TYPE_DIAL);
#line 2118 "about.c"
}


static const gchar* about_dial_real_get_uri (AboutPage* base) {
	const gchar* result;
	AboutDial* self;
	const gchar* _tmp0_;
#line 214 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = (AboutDial*) base;
#line 214 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp0_ = self->priv->_uri;
#line 214 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	result = _tmp0_;
#line 214 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	return result;
#line 2134 "about.c"
}


static void about_dial_real_set_uri (AboutPage* base, const gchar* value) {
	AboutDial* self;
#line 214 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = (AboutDial*) base;
#line 214 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	if (g_strcmp0 (value, about_dial_real_get_uri (base)) != 0) {
#line 2144 "about.c"
		const gchar* _tmp0_;
		gchar* _tmp1_;
#line 214 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_tmp0_ = value;
#line 214 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_tmp1_ = g_strdup (_tmp0_);
#line 214 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_g_free0 (self->priv->_uri);
#line 214 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		self->priv->_uri = _tmp1_;
#line 214 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		g_object_notify_by_pspec ((GObject *) self, about_dial_properties[ABOUT_DIAL_URI_PROPERTY]);
#line 2157 "about.c"
	}
}


static void about_dial_class_init (AboutDialClass * klass) {
#line 213 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	about_dial_parent_class = g_type_class_peek_parent (klass);
#line 213 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_type_class_add_private (klass, sizeof (AboutDialPrivate));
#line 213 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	((AboutPageClass *) klass)->get_contents = (void (*) (AboutPage *, MidoriView*, const gchar*)) about_dial_real_get_contents;
#line 213 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	ABOUT_PAGE_CLASS (klass)->get_uri = about_dial_real_get_uri;
#line 213 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	ABOUT_PAGE_CLASS (klass)->set_uri = about_dial_real_set_uri;
#line 213 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_about_dial_get_property;
#line 213 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_about_dial_set_property;
#line 213 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	G_OBJECT_CLASS (klass)->finalize = about_dial_finalize;
#line 213 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), ABOUT_DIAL_URI_PROPERTY, about_dial_properties[ABOUT_DIAL_URI_PROPERTY] = g_param_spec_string ("uri", "uri", "uri", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 2181 "about.c"
}


static void about_dial_instance_init (AboutDial * self) {
	gchar* _tmp0_;
#line 213 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self->priv = ABOUT_DIAL_GET_PRIVATE (self);
#line 214 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp0_ = g_strdup ("about:dial");
#line 214 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self->priv->_uri = _tmp0_;
#line 2193 "about.c"
}


static void about_dial_finalize (GObject * obj) {
	AboutDial * self;
#line 213 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, ABOUT_TYPE_DIAL, AboutDial);
#line 214 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_free0 (self->priv->_uri);
#line 213 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	G_OBJECT_CLASS (about_dial_parent_class)->finalize (obj);
#line 2205 "about.c"
}


GType about_dial_get_type (void) {
	static volatile gsize about_dial_type_id__volatile = 0;
	if (g_once_init_enter (&about_dial_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AboutDialClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) about_dial_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AboutDial), 0, (GInstanceInitFunc) about_dial_instance_init, NULL };
		GType about_dial_type_id;
		about_dial_type_id = g_type_register_static (ABOUT_TYPE_PAGE, "AboutDial", &g_define_type_info, 0);
		g_once_init_leave (&about_dial_type_id__volatile, about_dial_type_id);
	}
	return about_dial_type_id__volatile;
}


static void _vala_about_dial_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	AboutDial * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, ABOUT_TYPE_DIAL, AboutDial);
#line 213 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	switch (property_id) {
#line 213 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		case ABOUT_DIAL_URI_PROPERTY:
#line 213 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		g_value_set_string (value, about_page_get_uri ((AboutPage*) self));
#line 213 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		break;
#line 2232 "about.c"
		default:
#line 213 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 213 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		break;
#line 2238 "about.c"
	}
}


static void _vala_about_dial_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	AboutDial * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, ABOUT_TYPE_DIAL, AboutDial);
#line 213 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	switch (property_id) {
#line 213 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		case ABOUT_DIAL_URI_PROPERTY:
#line 213 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		about_page_set_uri ((AboutPage*) self, g_value_get_string (value));
#line 213 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		break;
#line 2254 "about.c"
		default:
#line 213 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 213 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		break;
#line 2260 "about.c"
	}
}


static void about_geolocation_real_get_contents (AboutPage* base, MidoriView* view, const gchar* uri) {
	AboutGeolocation * self;
	MidoriView* _tmp0_;
	const gchar* _tmp1_;
#line 231 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = (AboutGeolocation*) base;
#line 231 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (view != NULL);
#line 231 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (uri != NULL);
#line 232 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp0_ = view;
#line 232 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp1_ = uri;
#line 232 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	about_page_load_html ((AboutPage*) self, _tmp0_, "<html>\n" \
"                <body>\n" \
"                    <a href=\"http://dev.w3.org/geo/api/spec-source.ht" \
"ml\" id=\"method\"></a>\n" \
"                    <span id=\"locationInfo\"><noscript>No Geolocation" \
" without Javascript</noscript></span>\n" \
"                    <script>\n" \
"                        function displayLocation (position) {\n" \
"                            var geouri = 'geo:' + position.coords.lati" \
"tude + ',' + position.coords.longitude + ',' + position.coords.altitud" \
"e + ',u=' + position.coords.accuracy;\n" \
"                            document.getElementById('locationInfo').in" \
"nerHTML = '<a href=\"' + geouri + '\">' + geouri + '</a><br><code>'\n" \
"                                + ' timestamp: ' + position.timestamp\n" \
"                                + ' latitude: ' + position.coords.lati" \
"tude\n" \
"                                + ' longitude: ' + position.coords.lon" \
"gitude\n" \
"                                + ' altitude: ' + position.coords.alti" \
"tude + '<br>'\n" \
"                                + ' accuracy: ' + position.coords.accu" \
"racy\n" \
"                                + ' altitudeAccuracy: ' + position.coo" \
"rds.altitudeAccuracy\n" \
"                                + ' heading: ' + position.coords.headi" \
"ng\n" \
"                                + ' speed: ' + position.coords.speed\n" \
"                                + '</code>';\n" \
"                            }\n" \
"                            function handleError (error) {\n" \
"                                var errorMessage = '<b>' + ['Unknown e" \
"rror', 'Permission denied', 'Position failed', 'Timed out'][error.code" \
"] + '</b>';\n" \
"                                if (error.code == 3) document.getEleme" \
"ntById('locationInfo').innerHTML += (' ' + errorMessage);\n" \
"                                else document.getElementById('location" \
"Info').innerHTML = errorMessage;\n" \
"                            }\n" \
"                            if (navigator.geolocation) {\n" \
"                                var options = { enableHighAccuracy: tr" \
"ue, timeout: 60000, maximumAge: \"Infinite\" };\n" \
"                                if (navigator.geolocation.watchPositio" \
"n) {\n" \
"                                    document.getElementById('method')." \
"innerHTML = '<code>geolocation.watchPosition</code>:';\n" \
"                                    navigator.geolocation.watchPositio" \
"n(displayLocation, handleError, options);\n" \
"                                } else {\n" \
"                                    document.getElementById('method')." \
"innerHTML = '<code>geolocation.getCurrentPosition</code>:';\n" \
"                                    navigator.geolocation.getCurrentPo" \
"sition(displayLocation, handleError);\n" \
"                                }\n" \
"                            } else\n" \
"                                document.getElementById('locationInfo'" \
").innerHTML = 'Geolocation unavailable';\n" \
"                    </script>\n" \
"                </body>\n" \
"            </html>", _tmp1_);
#line 2281 "about.c"
}


AboutGeolocation* about_geolocation_construct (GType object_type) {
	AboutGeolocation * self = NULL;
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = (AboutGeolocation*) about_page_construct (object_type);
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	return self;
#line 2291 "about.c"
}


AboutGeolocation* about_geolocation_new (void) {
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	return about_geolocation_construct (ABOUT_TYPE_GEOLOCATION);
#line 2298 "about.c"
}


static const gchar* about_geolocation_real_get_uri (AboutPage* base) {
	const gchar* result;
	AboutGeolocation* self;
	const gchar* _tmp0_;
#line 230 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = (AboutGeolocation*) base;
#line 230 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp0_ = self->priv->_uri;
#line 230 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	result = _tmp0_;
#line 230 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	return result;
#line 2314 "about.c"
}


static void about_geolocation_real_set_uri (AboutPage* base, const gchar* value) {
	AboutGeolocation* self;
#line 230 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = (AboutGeolocation*) base;
#line 230 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	if (g_strcmp0 (value, about_geolocation_real_get_uri (base)) != 0) {
#line 2324 "about.c"
		const gchar* _tmp0_;
		gchar* _tmp1_;
#line 230 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_tmp0_ = value;
#line 230 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_tmp1_ = g_strdup (_tmp0_);
#line 230 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_g_free0 (self->priv->_uri);
#line 230 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		self->priv->_uri = _tmp1_;
#line 230 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		g_object_notify_by_pspec ((GObject *) self, about_geolocation_properties[ABOUT_GEOLOCATION_URI_PROPERTY]);
#line 2337 "about.c"
	}
}


static void about_geolocation_class_init (AboutGeolocationClass * klass) {
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	about_geolocation_parent_class = g_type_class_peek_parent (klass);
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_type_class_add_private (klass, sizeof (AboutGeolocationPrivate));
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	((AboutPageClass *) klass)->get_contents = (void (*) (AboutPage *, MidoriView*, const gchar*)) about_geolocation_real_get_contents;
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	ABOUT_PAGE_CLASS (klass)->get_uri = about_geolocation_real_get_uri;
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	ABOUT_PAGE_CLASS (klass)->set_uri = about_geolocation_real_set_uri;
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_about_geolocation_get_property;
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_about_geolocation_set_property;
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	G_OBJECT_CLASS (klass)->finalize = about_geolocation_finalize;
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), ABOUT_GEOLOCATION_URI_PROPERTY, about_geolocation_properties[ABOUT_GEOLOCATION_URI_PROPERTY] = g_param_spec_string ("uri", "uri", "uri", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 2361 "about.c"
}


static void about_geolocation_instance_init (AboutGeolocation * self) {
	gchar* _tmp0_;
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self->priv = ABOUT_GEOLOCATION_GET_PRIVATE (self);
#line 230 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp0_ = g_strdup ("about:geolocation");
#line 230 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self->priv->_uri = _tmp0_;
#line 2373 "about.c"
}


static void about_geolocation_finalize (GObject * obj) {
	AboutGeolocation * self;
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, ABOUT_TYPE_GEOLOCATION, AboutGeolocation);
#line 230 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_free0 (self->priv->_uri);
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	G_OBJECT_CLASS (about_geolocation_parent_class)->finalize (obj);
#line 2385 "about.c"
}


GType about_geolocation_get_type (void) {
	static volatile gsize about_geolocation_type_id__volatile = 0;
	if (g_once_init_enter (&about_geolocation_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AboutGeolocationClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) about_geolocation_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AboutGeolocation), 0, (GInstanceInitFunc) about_geolocation_instance_init, NULL };
		GType about_geolocation_type_id;
		about_geolocation_type_id = g_type_register_static (ABOUT_TYPE_PAGE, "AboutGeolocation", &g_define_type_info, 0);
		g_once_init_leave (&about_geolocation_type_id__volatile, about_geolocation_type_id);
	}
	return about_geolocation_type_id__volatile;
}


static void _vala_about_geolocation_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	AboutGeolocation * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, ABOUT_TYPE_GEOLOCATION, AboutGeolocation);
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	switch (property_id) {
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		case ABOUT_GEOLOCATION_URI_PROPERTY:
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		g_value_set_string (value, about_page_get_uri ((AboutPage*) self));
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		break;
#line 2412 "about.c"
		default:
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		break;
#line 2418 "about.c"
	}
}


static void _vala_about_geolocation_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	AboutGeolocation * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, ABOUT_TYPE_GEOLOCATION, AboutGeolocation);
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	switch (property_id) {
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		case ABOUT_GEOLOCATION_URI_PROPERTY:
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		about_page_set_uri ((AboutPage*) self, g_value_get_string (value));
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		break;
#line 2434 "about.c"
		default:
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 229 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		break;
#line 2440 "about.c"
	}
}


AboutRedirects* about_redirects_construct (GType object_type, const gchar* alias, const gchar* property) {
	AboutRedirects * self = NULL;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
#line 275 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_val_if_fail (alias != NULL, NULL);
#line 275 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_val_if_fail (property != NULL, NULL);
#line 275 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = (AboutRedirects*) about_page_construct (object_type);
#line 276 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp0_ = alias;
#line 276 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	about_page_set_uri ((AboutPage*) self, _tmp0_);
#line 277 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp1_ = property;
#line 277 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 277 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_free0 (self->priv->property);
#line 277 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self->priv->property = _tmp2_;
#line 275 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	return self;
#line 2470 "about.c"
}


AboutRedirects* about_redirects_new (const gchar* alias, const gchar* property) {
#line 275 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	return about_redirects_construct (ABOUT_TYPE_REDIRECTS, alias, property);
#line 2477 "about.c"
}


static void about_redirects_real_get_contents (AboutPage* base, MidoriView* view, const gchar* uri) {
	AboutRedirects * self;
	gchar* new_uri = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	MidoriView* _tmp2_;
	MidoriWebSettings* _tmp3_;
	MidoriWebSettings* _tmp4_;
	MidoriWebSettings* _tmp5_;
	const gchar* _tmp6_;
	const gchar* _tmp7_;
	MidoriView* _tmp10_;
	const gchar* _tmp11_;
#line 279 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = (AboutRedirects*) base;
#line 279 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (view != NULL);
#line 279 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (uri != NULL);
#line 280 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp0_ = uri;
#line 280 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 280 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	new_uri = _tmp1_;
#line 281 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp2_ = view;
#line 281 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_object_get (_tmp2_, "settings", &_tmp3_, NULL);
#line 281 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp4_ = _tmp3_;
#line 281 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp5_ = _tmp4_;
#line 281 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp6_ = self->priv->property;
#line 281 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_object_get ((GObject*) _tmp5_, _tmp6_, &new_uri, NULL);
#line 281 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_object_unref0 (_tmp5_);
#line 282 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp7_ = uri;
#line 282 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	if (g_strcmp0 (_tmp7_, "about:search") == 0) {
#line 2524 "about.c"
		const gchar* _tmp8_;
		gchar* _tmp9_;
#line 283 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_tmp8_ = new_uri;
#line 283 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_tmp9_ = midori_uri_for_search (_tmp8_, "");
#line 283 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_g_free0 (new_uri);
#line 283 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		new_uri = _tmp9_;
#line 2535 "about.c"
	}
#line 284 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp10_ = view;
#line 284 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp11_ = new_uri;
#line 284 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	midori_view_set_uri (_tmp10_, _tmp11_);
#line 279 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_free0 (new_uri);
#line 2545 "about.c"
}


static const gchar* about_redirects_real_get_uri (AboutPage* base) {
	const gchar* result;
	AboutRedirects* self;
	const gchar* _tmp0_;
#line 273 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = (AboutRedirects*) base;
#line 273 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp0_ = self->priv->_uri;
#line 273 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	result = _tmp0_;
#line 273 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	return result;
#line 2561 "about.c"
}


static void about_redirects_real_set_uri (AboutPage* base, const gchar* value) {
	AboutRedirects* self;
#line 273 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = (AboutRedirects*) base;
#line 273 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	if (g_strcmp0 (value, about_redirects_real_get_uri (base)) != 0) {
#line 2571 "about.c"
		const gchar* _tmp0_;
		gchar* _tmp1_;
#line 273 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_tmp0_ = value;
#line 273 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_tmp1_ = g_strdup (_tmp0_);
#line 273 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_g_free0 (self->priv->_uri);
#line 273 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		self->priv->_uri = _tmp1_;
#line 273 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		g_object_notify_by_pspec ((GObject *) self, about_redirects_properties[ABOUT_REDIRECTS_URI_PROPERTY]);
#line 2584 "about.c"
	}
}


static void about_redirects_class_init (AboutRedirectsClass * klass) {
#line 272 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	about_redirects_parent_class = g_type_class_peek_parent (klass);
#line 272 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_type_class_add_private (klass, sizeof (AboutRedirectsPrivate));
#line 272 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	((AboutPageClass *) klass)->get_contents = (void (*) (AboutPage *, MidoriView*, const gchar*)) about_redirects_real_get_contents;
#line 272 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	ABOUT_PAGE_CLASS (klass)->get_uri = about_redirects_real_get_uri;
#line 272 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	ABOUT_PAGE_CLASS (klass)->set_uri = about_redirects_real_set_uri;
#line 272 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_about_redirects_get_property;
#line 272 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_about_redirects_set_property;
#line 272 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	G_OBJECT_CLASS (klass)->finalize = about_redirects_finalize;
#line 272 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), ABOUT_REDIRECTS_URI_PROPERTY, about_redirects_properties[ABOUT_REDIRECTS_URI_PROPERTY] = g_param_spec_string ("uri", "uri", "uri", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 2608 "about.c"
}


static void about_redirects_instance_init (AboutRedirects * self) {
#line 272 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self->priv = ABOUT_REDIRECTS_GET_PRIVATE (self);
#line 2615 "about.c"
}


static void about_redirects_finalize (GObject * obj) {
	AboutRedirects * self;
#line 272 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, ABOUT_TYPE_REDIRECTS, AboutRedirects);
#line 273 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_free0 (self->priv->_uri);
#line 274 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_free0 (self->priv->property);
#line 272 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	G_OBJECT_CLASS (about_redirects_parent_class)->finalize (obj);
#line 2629 "about.c"
}


GType about_redirects_get_type (void) {
	static volatile gsize about_redirects_type_id__volatile = 0;
	if (g_once_init_enter (&about_redirects_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AboutRedirectsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) about_redirects_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AboutRedirects), 0, (GInstanceInitFunc) about_redirects_instance_init, NULL };
		GType about_redirects_type_id;
		about_redirects_type_id = g_type_register_static (ABOUT_TYPE_PAGE, "AboutRedirects", &g_define_type_info, 0);
		g_once_init_leave (&about_redirects_type_id__volatile, about_redirects_type_id);
	}
	return about_redirects_type_id__volatile;
}


static void _vala_about_redirects_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	AboutRedirects * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, ABOUT_TYPE_REDIRECTS, AboutRedirects);
#line 272 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	switch (property_id) {
#line 272 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		case ABOUT_REDIRECTS_URI_PROPERTY:
#line 272 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		g_value_set_string (value, about_page_get_uri ((AboutPage*) self));
#line 272 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		break;
#line 2656 "about.c"
		default:
#line 272 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 272 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		break;
#line 2662 "about.c"
	}
}


static void _vala_about_redirects_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	AboutRedirects * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, ABOUT_TYPE_REDIRECTS, AboutRedirects);
#line 272 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	switch (property_id) {
#line 272 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		case ABOUT_REDIRECTS_URI_PROPERTY:
#line 272 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		about_page_set_uri ((AboutPage*) self, g_value_get_string (value));
#line 272 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		break;
#line 2678 "about.c"
		default:
#line 272 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 272 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		break;
#line 2684 "about.c"
	}
}


static void about_manager_register (AboutManager* self, AboutPage* page) {
	GHashTable* _tmp0_;
	AboutPage* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	AboutPage* _tmp5_;
	AboutPage* _tmp6_;
#line 291 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (self != NULL);
#line 291 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (page != NULL);
#line 292 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp0_ = self->priv->about_pages;
#line 292 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp1_ = page;
#line 292 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp2_ = about_page_get_uri (_tmp1_);
#line 292 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp3_ = _tmp2_;
#line 292 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp4_ = g_strdup (_tmp3_);
#line 292 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp5_ = page;
#line 292 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp6_ = _g_object_ref0 (_tmp5_);
#line 292 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_hash_table_insert (_tmp0_, _tmp4_, _tmp6_);
#line 2717 "about.c"
}


static gboolean about_manager_about_content (AboutManager* self, MidoriView* view, const gchar* uri) {
	gboolean result = FALSE;
	AboutPage* page = NULL;
	GHashTable* _tmp0_;
	const gchar* _tmp1_;
	gconstpointer _tmp2_;
	AboutPage* _tmp3_;
#line 295 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 295 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_val_if_fail (view != NULL, FALSE);
#line 295 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_val_if_fail (uri != NULL, FALSE);
#line 296 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp0_ = self->priv->about_pages;
#line 296 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp1_ = uri;
#line 296 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp2_ = g_hash_table_lookup (_tmp0_, _tmp1_);
#line 296 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	page = (AboutPage*) _tmp2_;
#line 297 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp3_ = page;
#line 297 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	if (_tmp3_ != NULL) {
#line 2746 "about.c"
		AboutPage* _tmp4_;
		MidoriView* _tmp5_;
		const gchar* _tmp6_;
#line 298 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_tmp4_ = page;
#line 298 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_tmp5_ = view;
#line 298 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_tmp6_ = uri;
#line 298 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		about_page_get_contents (_tmp4_, _tmp5_, _tmp6_);
#line 299 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		result = TRUE;
#line 299 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		return result;
#line 2762 "about.c"
	}
#line 302 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	result = FALSE;
#line 302 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	return result;
#line 2768 "about.c"
}


static gboolean _about_manager_about_content_midori_view_about_content (MidoriView* _sender, const gchar* uri, gpointer self) {
	gboolean result;
	result = about_manager_about_content ((AboutManager*) self, _sender, uri);
#line 306 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	return result;
#line 2777 "about.c"
}


static void about_manager_tab_added (AboutManager* self, MidoriBrowser* browser, MidoriView* view) {
	MidoriView* _tmp0_;
#line 305 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (self != NULL);
#line 305 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (browser != NULL);
#line 305 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (view != NULL);
#line 306 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp0_ = view;
#line 306 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_signal_connect_object (_tmp0_, "about-content", (GCallback) _about_manager_about_content_midori_view_about_content, self, 0);
#line 2793 "about.c"
}


static void about_manager_tab_removed (AboutManager* self, MidoriBrowser* browser, MidoriView* view) {
	MidoriView* _tmp0_;
	guint _tmp1_;
#line 309 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (self != NULL);
#line 309 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (browser != NULL);
#line 309 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (view != NULL);
#line 310 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp0_ = view;
#line 310 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_signal_parse_name ("about-content", MIDORI_TYPE_VIEW, &_tmp1_, NULL, FALSE);
#line 310 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _about_manager_about_content_midori_view_about_content, self);
#line 2812 "about.c"
}


static void _about_manager_tab_added_midori_browser_add_tab (MidoriBrowser* _sender, MidoriView* tab, gpointer self) {
#line 317 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	about_manager_tab_added ((AboutManager*) self, _sender, tab);
#line 2819 "about.c"
}


static void _about_manager_tab_removed_midori_browser_remove_tab (MidoriBrowser* _sender, MidoriView* tab, gpointer self) {
#line 318 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	about_manager_tab_removed ((AboutManager*) self, _sender, tab);
#line 2826 "about.c"
}


static void about_manager_browser_added (AboutManager* self, MidoriBrowser* browser) {
	MidoriBrowser* _tmp0_;
	GList* _tmp1_;
	MidoriBrowser* _tmp5_;
	MidoriBrowser* _tmp6_;
#line 313 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (self != NULL);
#line 313 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (browser != NULL);
#line 314 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp0_ = browser;
#line 314 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp1_ = midori_browser_get_tabs (_tmp0_);
#line 2843 "about.c"
	{
		GList* tab_collection = NULL;
		GList* tab_it = NULL;
#line 314 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		tab_collection = _tmp1_;
#line 314 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		for (tab_it = tab_collection; tab_it != NULL; tab_it = tab_it->next) {
#line 2851 "about.c"
			MidoriView* _tmp2_;
			MidoriView* tab = NULL;
#line 314 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
			_tmp2_ = _g_object_ref0 ((MidoriView*) tab_it->data);
#line 314 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
			tab = _tmp2_;
#line 2858 "about.c"
			{
				MidoriBrowser* _tmp3_;
				MidoriView* _tmp4_;
#line 315 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
				_tmp3_ = browser;
#line 315 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
				_tmp4_ = tab;
#line 315 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
				about_manager_tab_added (self, _tmp3_, _tmp4_);
#line 314 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
				_g_object_unref0 (tab);
#line 2870 "about.c"
			}
		}
#line 314 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_g_list_free0 (tab_collection);
#line 2875 "about.c"
	}
#line 317 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp5_ = browser;
#line 317 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_signal_connect_object (_tmp5_, "add-tab", (GCallback) _about_manager_tab_added_midori_browser_add_tab, self, 0);
#line 318 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp6_ = browser;
#line 318 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_signal_connect_object (_tmp6_, "remove-tab", (GCallback) _about_manager_tab_removed_midori_browser_remove_tab, self, 0);
#line 2885 "about.c"
}


static void about_manager_browser_removed (AboutManager* self, MidoriBrowser* browser) {
	MidoriBrowser* _tmp0_;
	GList* _tmp1_;
	MidoriBrowser* _tmp5_;
	guint _tmp6_;
	MidoriBrowser* _tmp7_;
	guint _tmp8_;
#line 321 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (self != NULL);
#line 321 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (browser != NULL);
#line 322 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp0_ = browser;
#line 322 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp1_ = midori_browser_get_tabs (_tmp0_);
#line 2904 "about.c"
	{
		GList* tab_collection = NULL;
		GList* tab_it = NULL;
#line 322 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		tab_collection = _tmp1_;
#line 322 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		for (tab_it = tab_collection; tab_it != NULL; tab_it = tab_it->next) {
#line 2912 "about.c"
			MidoriView* _tmp2_;
			MidoriView* tab = NULL;
#line 322 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
			_tmp2_ = _g_object_ref0 ((MidoriView*) tab_it->data);
#line 322 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
			tab = _tmp2_;
#line 2919 "about.c"
			{
				MidoriBrowser* _tmp3_;
				MidoriView* _tmp4_;
#line 323 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
				_tmp3_ = browser;
#line 323 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
				_tmp4_ = tab;
#line 323 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
				about_manager_tab_removed (self, _tmp3_, _tmp4_);
#line 322 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
				_g_object_unref0 (tab);
#line 2931 "about.c"
			}
		}
#line 322 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_g_list_free0 (tab_collection);
#line 2936 "about.c"
	}
#line 325 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp5_ = browser;
#line 325 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_signal_parse_name ("add-tab", MIDORI_TYPE_BROWSER, &_tmp6_, NULL, FALSE);
#line 325 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_signal_handlers_disconnect_matched (_tmp5_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp6_, 0, NULL, (GCallback) _about_manager_tab_added_midori_browser_add_tab, self);
#line 326 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp7_ = browser;
#line 326 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_signal_parse_name ("remove-tab", MIDORI_TYPE_BROWSER, &_tmp8_, NULL, FALSE);
#line 326 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_signal_handlers_disconnect_matched (_tmp7_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp8_, 0, NULL, (GCallback) _about_manager_tab_removed_midori_browser_remove_tab, self);
#line 2950 "about.c"
}


static void _g_free0_ (gpointer var) {
#line 330 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	var = (g_free (var), NULL);
#line 2957 "about.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 330 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 2964 "about.c"
}


static void _about_manager_browser_added_midori_app_add_browser (MidoriApp* _sender, MidoriBrowser* browser, gpointer self) {
#line 345 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	about_manager_browser_added ((AboutManager*) self, browser);
#line 2971 "about.c"
}


void about_manager_activated (AboutManager* self, MidoriApp* app) {
	GHashFunc _tmp0_;
	GEqualFunc _tmp1_;
	GHashTable* _tmp2_;
	AboutWidgets* _tmp3_;
	AboutWidgets* _tmp4_;
	GHashTable* _tmp5_;
	AboutVersion* _tmp6_;
	AboutVersion* _tmp7_;
	GHashTable* _tmp8_;
	AboutVersion* _tmp9_;
	AboutVersion* _tmp10_;
	AboutPrivate* _tmp11_;
	AboutPrivate* _tmp12_;
	AboutPaths* _tmp13_;
	AboutPaths* _tmp14_;
	AboutGeolocation* _tmp15_;
	AboutGeolocation* _tmp16_;
	AboutRedirects* _tmp17_;
	AboutRedirects* _tmp18_;
	AboutRedirects* _tmp19_;
	AboutRedirects* _tmp20_;
	AboutRedirects* _tmp21_;
	AboutRedirects* _tmp22_;
	AboutDial* _tmp23_;
	AboutDial* _tmp24_;
	MidoriApp* _tmp25_;
	GList* _tmp26_;
	MidoriApp* _tmp29_;
#line 329 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (self != NULL);
#line 329 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (app != NULL);
#line 330 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp0_ = g_str_hash;
#line 330 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp1_ = g_str_equal;
#line 330 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp2_ = g_hash_table_new_full (_tmp0_, _tmp1_, _g_free0_, _g_object_unref0_);
#line 330 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_hash_table_unref0 (self->priv->about_pages);
#line 330 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self->priv->about_pages = _tmp2_;
#line 331 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp3_ = about_widgets_new ();
#line 331 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp4_ = _tmp3_;
#line 331 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	about_manager_register (self, (AboutPage*) _tmp4_);
#line 331 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_object_unref0 (_tmp4_);
#line 332 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp5_ = self->priv->about_pages;
#line 332 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp6_ = about_version_new ("about:", _tmp5_);
#line 332 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp7_ = _tmp6_;
#line 332 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	about_manager_register (self, (AboutPage*) _tmp7_);
#line 332 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_object_unref0 (_tmp7_);
#line 333 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp8_ = self->priv->about_pages;
#line 333 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp9_ = about_version_new ("about:version", _tmp8_);
#line 333 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp10_ = _tmp9_;
#line 333 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	about_manager_register (self, (AboutPage*) _tmp10_);
#line 333 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_object_unref0 (_tmp10_);
#line 334 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp11_ = about_private_new ();
#line 334 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp12_ = _tmp11_;
#line 334 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	about_manager_register (self, (AboutPage*) _tmp12_);
#line 334 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_object_unref0 (_tmp12_);
#line 335 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp13_ = about_paths_new ();
#line 335 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp14_ = _tmp13_;
#line 335 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	about_manager_register (self, (AboutPage*) _tmp14_);
#line 335 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_object_unref0 (_tmp14_);
#line 336 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp15_ = about_geolocation_new ();
#line 336 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp16_ = _tmp15_;
#line 336 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	about_manager_register (self, (AboutPage*) _tmp16_);
#line 336 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_object_unref0 (_tmp16_);
#line 337 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp17_ = about_redirects_new ("about:new", "tabhome");
#line 337 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp18_ = _tmp17_;
#line 337 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	about_manager_register (self, (AboutPage*) _tmp18_);
#line 337 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_object_unref0 (_tmp18_);
#line 338 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp19_ = about_redirects_new ("about:home", "homepage");
#line 338 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp20_ = _tmp19_;
#line 338 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	about_manager_register (self, (AboutPage*) _tmp20_);
#line 338 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_object_unref0 (_tmp20_);
#line 339 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp21_ = about_redirects_new ("about:search", "location-entry-search");
#line 339 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp22_ = _tmp21_;
#line 339 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	about_manager_register (self, (AboutPage*) _tmp22_);
#line 339 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_object_unref0 (_tmp22_);
#line 340 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp23_ = about_dial_new ();
#line 340 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp24_ = _tmp23_;
#line 340 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	about_manager_register (self, (AboutPage*) _tmp24_);
#line 340 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_object_unref0 (_tmp24_);
#line 342 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp25_ = app;
#line 342 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp26_ = midori_app_get_browsers (_tmp25_);
#line 3106 "about.c"
	{
		GList* browser_collection = NULL;
		GList* browser_it = NULL;
#line 342 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		browser_collection = _tmp26_;
#line 342 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		for (browser_it = browser_collection; browser_it != NULL; browser_it = browser_it->next) {
#line 3114 "about.c"
			MidoriBrowser* _tmp27_;
			MidoriBrowser* browser = NULL;
#line 342 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
			_tmp27_ = _g_object_ref0 ((MidoriBrowser*) browser_it->data);
#line 342 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
			browser = _tmp27_;
#line 3121 "about.c"
			{
				MidoriBrowser* _tmp28_;
#line 343 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
				_tmp28_ = browser;
#line 343 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
				about_manager_browser_added (self, _tmp28_);
#line 342 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
				_g_object_unref0 (browser);
#line 3130 "about.c"
			}
		}
#line 342 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_g_list_free0 (browser_collection);
#line 3135 "about.c"
	}
#line 345 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp29_ = app;
#line 345 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_signal_connect_object (_tmp29_, "add-browser", (GCallback) _about_manager_browser_added_midori_app_add_browser, self, 0);
#line 3141 "about.c"
}


void about_manager_deactivated (AboutManager* self) {
	MidoriApp* app = NULL;
	MidoriApp* _tmp0_;
	MidoriApp* _tmp1_;
	MidoriApp* _tmp2_;
	GList* _tmp3_;
	MidoriApp* _tmp6_;
	guint _tmp7_;
#line 348 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_return_if_fail (self != NULL);
#line 349 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp0_ = midori_extension_get_app ((MidoriExtension*) self);
#line 349 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 349 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	app = _tmp1_;
#line 350 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp2_ = app;
#line 350 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp3_ = midori_app_get_browsers (_tmp2_);
#line 3165 "about.c"
	{
		GList* browser_collection = NULL;
		GList* browser_it = NULL;
#line 350 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		browser_collection = _tmp3_;
#line 350 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		for (browser_it = browser_collection; browser_it != NULL; browser_it = browser_it->next) {
#line 3173 "about.c"
			MidoriBrowser* _tmp4_;
			MidoriBrowser* browser = NULL;
#line 350 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
			_tmp4_ = _g_object_ref0 ((MidoriBrowser*) browser_it->data);
#line 350 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
			browser = _tmp4_;
#line 3180 "about.c"
			{
				MidoriBrowser* _tmp5_;
#line 351 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
				_tmp5_ = browser;
#line 351 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
				about_manager_browser_removed (self, _tmp5_);
#line 350 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
				_g_object_unref0 (browser);
#line 3189 "about.c"
			}
		}
#line 350 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
		_g_list_free0 (browser_collection);
#line 3194 "about.c"
	}
#line 353 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp6_ = app;
#line 353 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_signal_parse_name ("add-browser", MIDORI_TYPE_APP, &_tmp7_, NULL, FALSE);
#line 353 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_signal_handlers_disconnect_matched (_tmp6_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp7_, 0, NULL, (GCallback) _about_manager_browser_added_midori_app_add_browser, self);
#line 355 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_hash_table_unref0 (self->priv->about_pages);
#line 355 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self->priv->about_pages = NULL;
#line 348 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_object_unref0 (app);
#line 3208 "about.c"
}


static void _about_manager_activated_midori_extension_activate (MidoriExtension* _sender, MidoriApp* app, gpointer self) {
#line 364 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	about_manager_activated ((AboutManager*) self, app);
#line 3215 "about.c"
}


static void _about_manager_deactivated_midori_extension_deactivate (MidoriExtension* _sender, gpointer self) {
#line 365 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	about_manager_deactivated ((AboutManager*) self);
#line 3222 "about.c"
}


AboutManager* about_manager_construct (GType object_type) {
	AboutManager * self = NULL;
#line 359 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = (AboutManager*) g_object_new (object_type, "name", "About pages", "description", "Internal about: handler", "version", "0.1", "authors", "André Stösel <andre@stoesel.de>", NULL);
#line 364 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_signal_connect_object ((MidoriExtension*) self, "activate", (GCallback) _about_manager_activated_midori_extension_activate, self, 0);
#line 365 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_signal_connect_object ((MidoriExtension*) self, "deactivate", (GCallback) _about_manager_deactivated_midori_extension_deactivate, self, 0);
#line 358 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	return self;
#line 3236 "about.c"
}


AboutManager* about_manager_new (void) {
#line 358 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	return about_manager_construct (ABOUT_TYPE_MANAGER);
#line 3243 "about.c"
}


static void about_manager_class_init (AboutManagerClass * klass) {
#line 288 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	about_manager_parent_class = g_type_class_peek_parent (klass);
#line 288 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	g_type_class_add_private (klass, sizeof (AboutManagerPrivate));
#line 288 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	G_OBJECT_CLASS (klass)->finalize = about_manager_finalize;
#line 3254 "about.c"
}


static void about_manager_instance_init (AboutManager * self) {
#line 288 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self->priv = ABOUT_MANAGER_GET_PRIVATE (self);
#line 3261 "about.c"
}


static void about_manager_finalize (GObject * obj) {
	AboutManager * self;
#line 288 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, ABOUT_TYPE_MANAGER, AboutManager);
#line 289 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_g_hash_table_unref0 (self->priv->about_pages);
#line 288 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	G_OBJECT_CLASS (about_manager_parent_class)->finalize (obj);
#line 3273 "about.c"
}


GType about_manager_get_type (void) {
	static volatile gsize about_manager_type_id__volatile = 0;
	if (g_once_init_enter (&about_manager_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AboutManagerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) about_manager_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AboutManager), 0, (GInstanceInitFunc) about_manager_instance_init, NULL };
		GType about_manager_type_id;
		about_manager_type_id = g_type_register_static (MIDORI_TYPE_EXTENSION, "AboutManager", &g_define_type_info, 0);
		g_once_init_leave (&about_manager_type_id__volatile, about_manager_type_id);
	}
	return about_manager_type_id__volatile;
}


MidoriExtension* extension_init (void) {
	MidoriExtension* result = NULL;
	AboutManager* _tmp0_;
#line 371 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	_tmp0_ = about_manager_new ();
#line 371 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	result = (MidoriExtension*) _tmp0_;
#line 371 "/usr/src/ports/midori/midori-0.5.11-2.x86_64/src/midori-0.5.11/extensions/about.vala"
	return result;
#line 3298 "about.c"
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



